# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SS3T_CSD_BETA1_METADATA = Metadata(
    id="3d7ce53d5c0f3941cd5c3621352793549ea67b37.boutiques",
    name="ss3t_csd_beta1",
    package="mrtrix3tissue",
    container_image_tag="brainlife/3tissue:5.2.8",
)


@dataclasses.dataclass
class Ss3tCsdBeta1Config:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class Ss3tCsdBeta1ResponseOdfOutputs(typing.NamedTuple):
    """
    Output object returned when calling `list[Ss3tCsdBeta1ResponseOdf](...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    odf: OutputPathType
    """output ODF image"""


@dataclasses.dataclass
class Ss3tCsdBeta1ResponseOdf:
    """
    pairs of input tissue response and output ODF images.
    """
    response: InputPathType
    """input tissue response"""
    odf: str
    """output ODF image"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(execution.input_file(self.response))
        cargs.append(self.odf)
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> Ss3tCsdBeta1ResponseOdfOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `Ss3tCsdBeta1ResponseOdfOutputs`).
        """
        ret = Ss3tCsdBeta1ResponseOdfOutputs(
            root=execution.output_file("."),
            odf=execution.output_file(self.odf),
        )
        return ret


class Ss3tCsdBeta1Outputs(typing.NamedTuple):
    """
    Output object returned when calling `ss3t_csd_beta1(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    response_odf: list[Ss3tCsdBeta1ResponseOdfOutputs]
    """Outputs from `Ss3tCsdBeta1ResponseOdf`.This is a list of outputs with the
    same length and order as the inputs."""


def ss3t_csd_beta1(
    dwi: InputPathType,
    response_odf: list[Ss3tCsdBeta1ResponseOdf],
    mask: InputPathType | None = None,
    bzero_pct: float | None = None,
    niter: int | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[Ss3tCsdBeta1Config] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> Ss3tCsdBeta1Outputs:
    """
    SS3T-CSD: beta 1 implementation
    
    * Dhollander, T. & Connelly, A. A novel iterative approach to reap the
    benefits of multi-tissue CSD from just single-shell (+b=0) diffusion MRI
    data. Proc Intl Soc Mag Reson Med, 2016, 3010.
    
    Author: MRTrix3Tissue Developers
    
    URL: https://3tissue.github.io/
    
    Args:
        dwi: the input diffusion-weighted image.
        response_odf: pairs of input tissue response and output ODF images.
        mask: only perform computation within the specified binary brain mask\
            image.
        bzero_pct: the threshold below which the amplitude of the FOD is\
            assumed to be zero, expressed as an absolute amplitude (default = 0).
        niter: the maximum number of iterations to perform for each voxel\
            (default = 50). Use '-niter 0' for a linear unconstrained spherical\
            deconvolution.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Ss3tCsdBeta1Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SS3T_CSD_BETA1_METADATA)
    cargs = []
    cargs.append("ss3t_csd_beta1")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if bzero_pct is not None:
        cargs.extend([
            "-bzero_pct",
            str(bzero_pct)
        ])
    if niter is not None:
        cargs.extend([
            "-niter",
            str(niter)
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(dwi))
    cargs.extend([a for c in [s.run(execution) for s in response_odf] for a in c])
    ret = Ss3tCsdBeta1Outputs(
        root=execution.output_file("."),
        response_odf=[i.outputs(execution) if hasattr(i, "outputs") else None for i in response_odf],
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SS3T_CSD_BETA1_METADATA",
    "Ss3tCsdBeta1Config",
    "Ss3tCsdBeta1Outputs",
    "Ss3tCsdBeta1ResponseOdf",
    "Ss3tCsdBeta1ResponseOdfOutputs",
    "ss3t_csd_beta1",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SYNTHSTRIP_METADATA = Metadata(
    id="404296260cedea4c55948a117336310c162854c6.boutiques",
    name="mri_synthstrip",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSynthstripOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_synthstrip(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image_file: OutputPathType | None
    """Stripped brain image output."""
    output_mask_file: OutputPathType | None
    """Binary brain mask output."""


def mri_synthstrip(
    image: InputPathType,
    output_image: InputPathType | None = None,
    mask: InputPathType | None = None,
    gpu: bool = False,
    border: float | None = 1,
    exclude_csf: bool = False,
    model_weights: InputPathType | None = None,
    runner: Runner | None = None,
) -> MriSynthstripOutputs:
    """
    Robust, universal skull-stripping for brain images of any type.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        image: Input image to skullstrip.
        output_image: Save stripped image to path.
        mask: Save binary brain mask to path.
        gpu: Use the GPU.
        border: Mask border threshold in mm. Default is 1.
        exclude_csf: Exclude CSF from brain border.
        model_weights: Alternative model weights.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSynthstripOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SYNTHSTRIP_METADATA)
    cargs = []
    cargs.append("mri_synthstrip")
    cargs.extend([
        "-i",
        execution.input_file(image)
    ])
    if output_image is not None:
        cargs.extend([
            "-o",
            "[" + execution.input_file(output_image) + "]"
        ])
    if mask is not None:
        cargs.extend([
            "-m",
            "[" + execution.input_file(mask) + "]"
        ])
    if gpu:
        cargs.append("[" + "-g" + "]")
    if border is not None:
        cargs.extend([
            "-b",
            "[" + str(border) + "]"
        ])
    if exclude_csf:
        cargs.append("[" + "--no-csf" + "]")
    if model_weights is not None:
        cargs.extend([
            "--model",
            "[" + execution.input_file(model_weights) + "]"
        ])
    ret = MriSynthstripOutputs(
        root=execution.output_file("."),
        output_image_file=execution.output_file(pathlib.Path(output_image).name) if (output_image is not None) else None,
        output_mask_file=execution.output_file(pathlib.Path(mask).name) if (mask is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SYNTHSTRIP_METADATA",
    "MriSynthstripOutputs",
    "mri_synthstrip",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

HIST2PROB_METADATA = Metadata(
    id="5072c0a1058e5f776baf142ca06c38b53022df66.boutiques",
    name="hist2prob",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class Hist2probOutputs(typing.NamedTuple):
    """
    Output object returned when calling `hist2prob(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_probability_map: OutputPathType
    """Output probability map converted from histogram"""


def hist2prob(
    image: InputPathType,
    size: int,
    low_threshold: float,
    high_threshold: float,
    runner: Runner | None = None,
) -> Hist2probOutputs:
    """
    Converts a histogram image to a probability map based on specified thresholds.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        image: Input histogram image.
        size: Size of the histogram.
        low_threshold: Lower threshold for probability conversion.
        high_threshold: Higher threshold for probability conversion.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Hist2probOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(HIST2PROB_METADATA)
    cargs = []
    cargs.append("hist2prob")
    cargs.append(execution.input_file(image))
    cargs.append(str(size))
    cargs.append(str(low_threshold))
    cargs.append(str(high_threshold))
    ret = Hist2probOutputs(
        root=execution.output_file("."),
        output_probability_map=execution.output_file(pathlib.Path(image).name + "_probability_map.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "HIST2PROB_METADATA",
    "Hist2probOutputs",
    "hist2prob",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_SBCA_METADATA = Metadata(
    id="199812ccc7fd2828b7a4a8dfec9e624e99e68709.boutiques",
    name="fsl_sbca",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslSbcaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_sbca(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_seed_mask_image: OutputPathType
    """Output seed mask image"""
    output_seed_mask_image_base: OutputPathType
    """Output seed mask image"""
    output_target_time_courses: OutputPathType
    """Output target time courses"""
    output_confound_time_courses: OutputPathType
    """Output confound time courses"""


def fsl_sbca(
    infile: InputPathType,
    seed: InputPathType,
    target: InputPathType,
    out: str,
    reg_flag: bool = False,
    conf_files: list[InputPathType] | None = None,
    seed_data: InputPathType | None = None,
    binarise_flag: bool = False,
    mean_flag: bool = False,
    abs_cc_flag: bool = False,
    order: float | None = None,
    out_seeds_flag: bool = False,
    out_seedmask_flag: bool = False,
    out_ttcs_flag: bool = False,
    out_conf_flag: bool = False,
    verbose_flag: bool = False,
    help_flag: bool = False,
    runner: Runner | None = None,
) -> FslSbcaOutputs:
    """
    Performs seed-based correlation analysis on FMRI data using either a single seed
    coordinate or a seed mask.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        infile: Input file name (4D image file).
        seed: Seed voxel coordinate or file name of seed mask (3D/4D file).
        target: File name of target mask(s) (3D or 4D file).
        out: Output file base name.
        reg_flag: Perform time series regression rather than classification to\
            targets.
        conf_files: File name (or comma-separated list of file names) for\
            confound ASCII text files.
        seed_data: File name of 4D data file for the seed.
        binarise_flag: Binarise spatial maps prior to calculation of time\
            courses.
        mean_flag: Use mean instead of Eigenvariates for calculation of time\
            courses.
        abs_cc_flag: Use maximum absolute value instead of maximum value of the\
            cross-correlations.
        order: Number of Eigenvariates (default 1).
        out_seeds_flag: Output seed mask image as <basename>_seeds.
        out_seedmask_flag: Output seed mask image as <basename>_seedmask.
        out_ttcs_flag: Output target time courses as <basename>_ttc<X>.txt.
        out_conf_flag: Output confound time courses as <basename>_confounds.txt.
        verbose_flag: Switch on diagnostic messages.
        help_flag: Display help text.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslSbcaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_SBCA_METADATA)
    cargs = []
    cargs.append("fsl_sbca")
    cargs.extend([
        "--in",
        execution.input_file(infile)
    ])
    cargs.extend([
        "--seed",
        execution.input_file(seed)
    ])
    cargs.extend([
        "--target",
        execution.input_file(target)
    ])
    cargs.extend([
        "--out",
        out
    ])
    if reg_flag:
        cargs.append("--reg")
    if conf_files is not None:
        cargs.extend([
            "--conf",
            *[execution.input_file(f) for f in conf_files]
        ])
    if seed_data is not None:
        cargs.extend([
            "--seeddata",
            execution.input_file(seed_data)
        ])
    if binarise_flag:
        cargs.append("--bin")
    if mean_flag:
        cargs.append("--mean")
    if abs_cc_flag:
        cargs.append("--abscc")
    if order is not None:
        cargs.extend([
            "--order",
            str(order)
        ])
    if out_seeds_flag:
        cargs.append("--out_seeds")
    if out_seedmask_flag:
        cargs.append("--out_seedmask")
    if out_ttcs_flag:
        cargs.append("--out_ttcs")
    if out_conf_flag:
        cargs.append("--out_conf")
    if verbose_flag:
        cargs.append("-v")
    if help_flag:
        cargs.append("-h")
    ret = FslSbcaOutputs(
        root=execution.output_file("."),
        output_seed_mask_image=execution.output_file(out + "_seeds"),
        output_seed_mask_image_base=execution.output_file(out + "_seedmask"),
        output_target_time_courses=execution.output_file(out + "_ttc<X>.txt"),
        output_confound_time_courses=execution.output_file(out + "_confounds.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_SBCA_METADATA",
    "FslSbcaOutputs",
    "fsl_sbca",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_LABEL_CALC_METADATA = Metadata(
    id="4566c0b5206cd4d9fc63822cdb713e50b1ee033e.boutiques",
    name="mris_label_calc",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisLabelCalcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_label_calc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_label: OutputPathType
    """The resulting label file after operation"""


def mris_label_calc(
    command: typing.Literal["union", "intersect", "invert", "erode", "dilate"],
    input1: InputPathType,
    input2: InputPathType,
    output: str,
    runner: Runner | None = None,
) -> MrisLabelCalcOutputs:
    """
    Tool for surface label calculations.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        command: Command to perform on input labels.
        input1: First input label file.
        input2: Second input label file (used for 'invert', 'erode', 'dilate'\
            operations).
        output: Output label file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisLabelCalcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_LABEL_CALC_METADATA)
    cargs = []
    cargs.append("mris_label_calc")
    cargs.append(command)
    cargs.append(execution.input_file(input1))
    cargs.append(execution.input_file(input2))
    cargs.append(output)
    ret = MrisLabelCalcOutputs(
        root=execution.output_file("."),
        output_label=execution.output_file(output + ".label"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_LABEL_CALC_METADATA",
    "MrisLabelCalcOutputs",
    "mris_label_calc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_NLFILTER_METADATA = Metadata(
    id="c44a60efcccca403f44c82f08afd31e3af464d00.boutiques",
    name="mri_nlfilter",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriNlfilterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_nlfilter(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """The processed image output file."""


def mri_nlfilter(
    input_image: InputPathType,
    output_image: str,
    blur_sigma: float | None = None,
    gaussian_sigma: float | None = None,
    mean_flag: bool = False,
    window_size: float | None = None,
    cplov_flag: bool = False,
    minmax_flag: bool = False,
    no_offsets_flag: bool = False,
    no_crop_flag: bool = False,
    version_flag: bool = False,
    help_flag: bool = False,
    runner: Runner | None = None,
) -> MriNlfilterOutputs:
    """
    This program processes an image using a nonlocal filter and writes the results
    to an output file. It supports different filtering methods such as median,
    Gaussian, and mean.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_image: The input image file to be processed.
        output_image: The output image file where the processed image will be\
            saved.
        blur_sigma: Specify sigma of the blurring kernel. Default is 0.500.
        gaussian_sigma: Filter with Gaussian instead of median. Requires sigma\
            value.
        mean_flag: Filter with mean instead of median.
        window_size: Specify window size used for offset calculation. Default\
            is 3.
        cplov_flag: Filter with cplov.
        minmax_flag: Filter with minmax.
        no_offsets_flag: Don't use offsets, just apply standard filters.
        no_crop_flag: Don't crop to >0 region of image.
        version_flag: Display version number.
        help_flag: Display help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriNlfilterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_NLFILTER_METADATA)
    cargs = []
    cargs.append("mri_nlfilter")
    cargs.append(execution.input_file(input_image))
    cargs.append(output_image)
    if blur_sigma is not None:
        cargs.extend([
            "-blur",
            str(blur_sigma)
        ])
    if gaussian_sigma is not None:
        cargs.extend([
            "-gaussian",
            str(gaussian_sigma)
        ])
    if mean_flag:
        cargs.append("-mean")
    if window_size is not None:
        cargs.extend([
            "-w",
            str(window_size)
        ])
    if cplov_flag:
        cargs.append("-cplov")
    if minmax_flag:
        cargs.append("-minmax")
    if no_offsets_flag:
        cargs.append("-n")
    if no_crop_flag:
        cargs.append("-nc")
    if version_flag:
        cargs.append("--version")
    if help_flag:
        cargs.append("--help")
    ret = MriNlfilterOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_image),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_NLFILTER_METADATA",
    "MriNlfilterOutputs",
    "mri_nlfilter",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_PMAKE_METADATA = Metadata(
    id="dd00ff607795956546fa917b74a471d7811886b3.boutiques",
    name="mris_pmake",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisPmakeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_pmake(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_pmake(
    subject: str,
    hemisphere: str,
    options_file: str | None = "options.txt",
    working_dir: str | None = ".",
    listen_mode: bool = False,
    listen_on_port: float | None = None,
    surface0: str | None = "inflated",
    surface1: str | None = "smoothwm",
    curve0: str | None = "smoothwm.H.crv",
    curve1: str | None = "sulc",
    use_abs_curvs: bool = False,
    mpm_prog: str | None = None,
    mpm_args: str | None = None,
    runner: Runner | None = None,
) -> MrisPmakeOutputs:
    """
    Calculates paths and related costs on FreeSurfer surfaces based on an edge cost
    and Dijkstra's algorithm.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Set the subject to <subj>.
        hemisphere: The hemisphere to process.
        options_file: The main configuration file specifying the startup\
            run-time behaviour.
        working_dir: The working directory.
        listen_mode: Start in LISTEN mode without calculating a path.
        listen_on_port: Create the server port on specified port and do nothing\
            else.
        surface0: The main mesh surface to read.
        surface1: The aux mesh surface to read.
        curve0: The main curvature function maps.
        curve1: The aux curvature function maps.
        use_abs_curvs: Use absolute values on each curvature map.
        mpm_prog: The mpmProg to run.
        mpm_args: Arguments for the specified mpmProg.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisPmakeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_PMAKE_METADATA)
    cargs = []
    cargs.append("mris_pmake")
    if options_file is not None:
        cargs.extend([
            "--optionsFile",
            options_file
        ])
    if working_dir is not None:
        cargs.extend([
            "--dir",
            working_dir
        ])
    if listen_mode:
        cargs.append("--listen")
    if listen_on_port is not None:
        cargs.extend([
            "--listenOnPort",
            str(listen_on_port)
        ])
    cargs.extend([
        "--subject",
        subject
    ])
    cargs.extend([
        "--hemi",
        hemisphere
    ])
    if surface0 is not None:
        cargs.extend([
            "--surface0",
            surface0
        ])
    if surface1 is not None:
        cargs.extend([
            "--surface1",
            surface1
        ])
    if curve0 is not None:
        cargs.extend([
            "--curve0",
            curve0
        ])
    if curve1 is not None:
        cargs.extend([
            "--curve1",
            curve1
        ])
    if use_abs_curvs:
        cargs.append("--useAbsCurvs")
    if mpm_prog is not None:
        cargs.extend([
            "--mpmProg",
            mpm_prog
        ])
    if mpm_args is not None:
        cargs.extend([
            "--mpmArgs",
            mpm_args
        ])
    ret = MrisPmakeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_PMAKE_METADATA",
    "MrisPmakeOutputs",
    "mris_pmake",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_CA_TRAIN_METADATA = Metadata(
    id="432e0861913c8c1346f736846e22c0107ee5337f.boutiques",
    name="mri_ca_train",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriCaTrainOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_ca_train(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_ca_train(
    subjects: list[str],
    output_gca: str,
    segmentation: str,
    transform: str | None = None,
    mask_volume: str | None = None,
    node_spacing: str | None = None,
    prior_spacing: str | None = None,
    input_training: list[str] | None = None,
    makesym: list[str] | None = None,
    check_symmetry: list[str] | None = None,
    sanity_check: bool = False,
    threads: int | None = None,
    done_file: str | None = None,
    runner: Runner | None = None,
) -> MriCaTrainOutputs:
    """
    Trains GCA data with multiple subjects using provided segmentation volumes and
    other configuration.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjects: List of subject directories under the SUBJECTS_DIR. Each is a\
            path relative to the subject's MRI directory.
        output_gca: Output GCA file name.
        segmentation: Segmentation volume directory relative to each subject's\
            MRI path.
        transform: Atlas transform path relative to each subject's MRI\
            transforms directory.
        mask_volume: Volume name used as a mask, path relative to each\
            subject's MRI directory.
        node_spacing: Spacing of classifiers in canonical space.
        prior_spacing: Spacing of class priors in canonical space.
        input_training: Specifying training data, path relative to each\
            subject's MRI directory. Can specify multiple inputs.
        makesym: Symmetrize an already existing atlas. Specify input GCA and\
            symmetrized GCA.
        check_symmetry: Check the symmetry of an already existing atlas.\
            Specify input GCA and symmetrized GCA.
        sanity_check: Conduct sanity-check of labels for obvious edit errors.
        threads: Specify number of threads to use (also known as -nthreads).
        done_file: Create DoneFile when done (contents: 0=ok, 1=error).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriCaTrainOutputs`).
    """
    if not (1 <= len(subjects)): 
        raise ValueError(f"Length of 'subjects' must be greater than 1 but was {len(subjects)}")
    if makesym is not None and not (len(makesym) <= 2): 
        raise ValueError(f"Length of 'makesym' must be less than 2 but was {len(makesym)}")
    if check_symmetry is not None and not (len(check_symmetry) <= 2): 
        raise ValueError(f"Length of 'check_symmetry' must be less than 2 but was {len(check_symmetry)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_CA_TRAIN_METADATA)
    cargs = []
    cargs.append("mri_ca_train")
    cargs.extend(subjects)
    cargs.append(output_gca)
    cargs.extend([
        "-seg",
        segmentation
    ])
    if transform is not None:
        cargs.extend([
            "-xform",
            transform
        ])
    if mask_volume is not None:
        cargs.extend([
            "-mask",
            mask_volume
        ])
    if node_spacing is not None:
        cargs.extend([
            "-node_spacing",
            node_spacing
        ])
    if prior_spacing is not None:
        cargs.extend([
            "-prior_spacing",
            prior_spacing
        ])
    if input_training is not None:
        cargs.extend([
            "-input",
            *input_training
        ])
    if makesym is not None:
        cargs.extend([
            "-makesym",
            *makesym
        ])
    if check_symmetry is not None:
        cargs.extend([
            "-checksym",
            *check_symmetry
        ])
    if sanity_check:
        cargs.append("-check")
    if threads is not None:
        cargs.extend([
            "-threads",
            str(threads)
        ])
    if done_file is not None:
        cargs.extend([
            "-done",
            done_file
        ])
    ret = MriCaTrainOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_CA_TRAIN_METADATA",
    "MriCaTrainOutputs",
    "mri_ca_train",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IM2NIML_METADATA = Metadata(
    id="3c92592db9d506b4424ac028f92405630d2fda18.boutiques",
    name="im2niml",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class Im2nimlOutputs(typing.NamedTuple):
    """
    Output object returned when calling `im2niml(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    niml_output: OutputPathType
    """NIML element"""


def im2niml(
    input_files: list[InputPathType],
    runner: Runner | None = None,
) -> Im2nimlOutputs:
    """
    Converts the input image(s) to a text-based NIML element and writes the result
    to stdout.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_files: Input image file(s) (e.g. image.jpg).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Im2nimlOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IM2NIML_METADATA)
    cargs = []
    cargs.append("im2niml")
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = Im2nimlOutputs(
        root=execution.output_file("."),
        niml_output=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IM2NIML_METADATA",
    "Im2nimlOutputs",
    "im2niml",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_NWARP_APPLY_METADATA = Metadata(
    id="0a5385bf1fc9acdee0016adc133f63a8ec8a4e36.boutiques",
    name="3dNwarpApply",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dNwarpApplyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_nwarp_apply(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    warped_output: OutputPathType | None
    """Warped output dataset"""
    generated_warp: OutputPathType | None
    """Warp dataset generated during application"""


def v_3d_nwarp_apply(
    nwarp: str,
    source: str,
    iwarp: bool = False,
    master: str | None = None,
    newgrid: str | None = None,
    dxyz: str | None = None,
    interp: str | None = None,
    ainterp: str | None = None,
    prefix: str | None = None,
    suffix: str | None = None,
    short: bool = False,
    wprefix: str | None = None,
    quiet: bool = False,
    verb: bool = False,
    runner: Runner | None = None,
) -> V3dNwarpApplyOutputs:
    """
    Program to apply a nonlinear 3D warp saved from 3dQwarp (or 3dNwarpCat, etc.) to
    a 3D dataset, to produce a warped version of the source dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        nwarp: The name of the 3D warp dataset. Multiple warps can be\
            catenated.
        source: The name of the source dataset to be warped. Multiple datasets\
            can be supplied.
        iwarp: Invert the warp specified in '-nwarp'.
        master: The name of the master dataset which defines the output grid.
        newgrid: The new grid spacing (cubical voxels, in mm).
        dxyz: Specify a different grid spacing (cubical voxels, in mm).
        interp: The interpolation mode ('NN', 'linear', 'cubic', 'quintic',\
            'wsinc5').
        ainterp: Specify a different interpolation mode for the data than the\
            warp.
        prefix: The name of the new output dataset. Multiple names can be\
            supplied if more than one source dataset is input.
        suffix: Change the default suffix '_Nwarp' to a user-defined suffix.
        short: Write output dataset using 16-bit short integers rather than the\
            usual 32-bit floats.
        wprefix: Save every warp generated in the process to a separate\
            dataset.
        quiet: Don't be verbose.
        verb: Be extra verbose.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dNwarpApplyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_NWARP_APPLY_METADATA)
    cargs = []
    cargs.append("3dNwarpApply")
    cargs.extend([
        "-nwarp",
        nwarp
    ])
    if iwarp:
        cargs.append("-iwarp")
    cargs.extend([
        "-source",
        source
    ])
    if master is not None:
        cargs.extend([
            "-master",
            master
        ])
    if newgrid is not None:
        cargs.extend([
            "-newgrid",
            newgrid
        ])
    if dxyz is not None:
        cargs.extend([
            "-dxyz",
            dxyz
        ])
    if interp is not None:
        cargs.extend([
            "-interp",
            interp
        ])
    if ainterp is not None:
        cargs.extend([
            "-ainterp",
            ainterp
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if suffix is not None:
        cargs.extend([
            "-suffix",
            suffix
        ])
    if short:
        cargs.append("-short")
    if wprefix is not None:
        cargs.extend([
            "-wprefix",
            wprefix
        ])
    if quiet:
        cargs.append("-quiet")
    if verb:
        cargs.append("-verb")
    ret = V3dNwarpApplyOutputs(
        root=execution.output_file("."),
        warped_output=execution.output_file(prefix + "_" + source + "_warped.nii.gz") if (prefix is not None) else None,
        generated_warp=execution.output_file(wprefix + "_warp_????.nii.gz") if (wprefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dNwarpApplyOutputs",
    "V_3D_NWARP_APPLY_METADATA",
    "v_3d_nwarp_apply",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DDOT_METADATA = Metadata(
    id="4d259267b87f75dc1b81e232092499e6d326d8fd.boutiques",
    name="3ddot",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3ddotOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3ddot(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    result: OutputPathType
    """Resulting coefficient or statistical values printed to stdout"""


def v_3ddot(
    input_datasets: list[InputPathType],
    mask: InputPathType | None = None,
    mrange: list[float] | None = None,
    demean: bool = False,
    docor: bool = False,
    dodot: bool = False,
    docoef: bool = False,
    dosums: bool = False,
    doeta2: bool = False,
    dodice: bool = False,
    show_labels: bool = False,
    upper: bool = False,
    full: bool = False,
    v_1_d: bool = False,
    niml: bool = False,
    runner: Runner | None = None,
) -> V3ddotOutputs:
    """
    Computes correlation coefficients between sub-brick pairs.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_datasets: List of input datasets to be used (e.g. img1+orig,\
            img2+orig).
        mask: Dataset to be used as a mask; only voxels with nonzero values\
            will be averaged.
        mrange: Restrict mask values to those between a and b (inclusive) for\
            masking purposes.
        demean: Remove the mean from each volume prior to computing the\
            correlation.
        docor: Return the correlation coefficient (default).
        dodot: Return the dot product (unscaled).
        docoef: Return the least square fit coefficients {a,b}.
        dosums: Return xbar, ybar, variance, covariance, and correlation\
            coefficient.
        doeta2: Return eta-squared (Cohen, NeuroImage 2008).
        dodice: Return the Dice coefficient (the Sorensen-Dice index).
        show_labels: Print sub-brick labels to help identify what is being\
            correlated.
        upper: Compute upper triangular matrix.
        full: Compute the whole matrix.
        v_1_d: Add comment headings for the 1D format.
        niml: Write output in NIML 1D format.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3ddotOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DDOT_METADATA)
    cargs = []
    cargs.append("3ddot")
    cargs.extend([execution.input_file(f) for f in input_datasets])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if mrange is not None:
        cargs.extend([
            "-mrange",
            *map(str, mrange)
        ])
    if demean:
        cargs.append("-demean")
    if docor:
        cargs.append("-docor")
    if dodot:
        cargs.append("-dodot")
    if docoef:
        cargs.append("-docoef")
    if dosums:
        cargs.append("-dosums")
    if doeta2:
        cargs.append("-doeta2")
    if dodice:
        cargs.append("-dodice")
    if show_labels:
        cargs.append("-show_labels")
    if upper:
        cargs.append("-upper")
    if full:
        cargs.append("-full")
    if v_1_d:
        cargs.append("-1D")
    if niml:
        cargs.append("-NIML")
    ret = V3ddotOutputs(
        root=execution.output_file("."),
        result=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3ddotOutputs",
    "V_3DDOT_METADATA",
    "v_3ddot",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PULSE_METADATA = Metadata(
    id="9d77ff6fd1076f545b6660ae20968e6ff549f4fa.boutiques",
    name="pulse",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class PulseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `pulse(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_pulse_sequence_matrix: OutputPathType
    """Pulse sequence matrix output"""


def pulse(
    input_file: InputPathType,
    output_base: str,
    seq: str | None = "epi",
    angle: float | None = 90,
    te: float | None = 0.03,
    tr: float | None = 3,
    trslc: float | None = 0.12,
    nx: float | None = 64,
    ny: float | None = 64,
    dx: float | None = 0.004,
    dy: float | None = 0.004,
    max_g: float | None = 0.055,
    riset: float | None = 0.00022,
    bw: float | None = 100000,
    numvol: float | None = 1,
    numslc: float | None = 1,
    slcthk: float | None = 0.006,
    gap: float | None = 0,
    zstart: float | None = 0,
    slcdir: str | None = "z-",
    phasedir: str | None = "y+",
    readdir: str | None = "x+",
    verbose_flag: bool = False,
    kcoord_flag: bool = False,
    cover: float | None = None,
    runner: Runner | None = None,
) -> PulseOutputs:
    """
    Generates a pulse sequence matrix for a given digital brain image.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_file: 4D digital brain, resolution can be any.
        output_base: Output base name.
        seq: Type of pulse sequence; default=epi (epi OR ge).
        angle: Flip angle in degrees; default=90.
        te: The time from the first RF to the first echo; default=0.03s.
        tr: The time between the two RF pulses applied on the same part of the\
            object; default=3s.
        trslc: The time that takes for the acquisition of one slice;\
            default=0.12s.
        nx: Resolution in x of the output image; default=64.
        ny: Resolution in y of the output image; default=64.
        dx: Image voxel x-dimension; default=0.004m.
        dy: Image voxel y-dimension; default=0.004m.
        max_g: Maximum gradient strength; default=0.055 T/m.
        riset: Time it takes for the gradient to reach its max value;\
            default=0.00022s.
        bw: Receiving bandwidth; default=100000Hz.
        numvol: Number of volumes; default=1.
        numslc: Number of slices; default=1.
        slcthk: Slice thickness; default=0.006m.
        gap: Gap between the slices in meters; default=0m.
        zstart: The lowest position in the slice direction in meters;\
            default=0m.
        slcdir: Slice acquisition direction/orientation; default=z- (x+,x-,\
            y+,y- or z+,or z-).
        phasedir: Phase encode direction/orientation; default=y+ (x+,x-, y+,y-\
            or z+,or z-).
        readdir: Read-out direction/orientation; default=x+ (x+,x-, y+,y- or\
            z+,or z-).
        verbose_flag: Switch on diagnostic messages.
        kcoord_flag: Save k-space coordinates; default=no.
        cover: Phase partial Fourier coverage in percentage; default=100\
            (min=50, max=100).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PulseOutputs`).
    """
    if cover is not None and not (50 <= cover <= 100): 
        raise ValueError(f"'cover' must be between 50 <= x <= 100 but was {cover}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(PULSE_METADATA)
    cargs = []
    cargs.append("pulse")
    cargs.extend([
        "-i",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "-o",
        output_base
    ])
    if seq is not None:
        cargs.extend([
            "--seq",
            seq
        ])
    if angle is not None:
        cargs.extend([
            "--angle",
            str(angle)
        ])
    if te is not None:
        cargs.extend([
            "--te",
            str(te)
        ])
    if tr is not None:
        cargs.extend([
            "--tr",
            str(tr)
        ])
    if trslc is not None:
        cargs.extend([
            "--trslc",
            str(trslc)
        ])
    if nx is not None:
        cargs.extend([
            "--nx",
            str(nx)
        ])
    if ny is not None:
        cargs.extend([
            "--ny",
            str(ny)
        ])
    if dx is not None:
        cargs.extend([
            "--dx",
            str(dx)
        ])
    if dy is not None:
        cargs.extend([
            "--dy",
            str(dy)
        ])
    if max_g is not None:
        cargs.extend([
            "--maxG",
            str(max_g)
        ])
    if riset is not None:
        cargs.extend([
            "--riset",
            str(riset)
        ])
    if bw is not None:
        cargs.extend([
            "--bw",
            str(bw)
        ])
    if numvol is not None:
        cargs.extend([
            "--numvol",
            str(numvol)
        ])
    if numslc is not None:
        cargs.extend([
            "--numslc",
            str(numslc)
        ])
    if slcthk is not None:
        cargs.extend([
            "--slcthk",
            str(slcthk)
        ])
    if gap is not None:
        cargs.extend([
            "--gap",
            str(gap)
        ])
    if zstart is not None:
        cargs.extend([
            "--zstart",
            str(zstart)
        ])
    if slcdir is not None:
        cargs.extend([
            "--slcdir",
            slcdir
        ])
    if phasedir is not None:
        cargs.extend([
            "--phasedir",
            phasedir
        ])
    if readdir is not None:
        cargs.extend([
            "--readdir",
            readdir
        ])
    if verbose_flag:
        cargs.append("-v")
    if kcoord_flag:
        cargs.append("-k")
    if cover is not None:
        cargs.extend([
            "--cover",
            str(cover)
        ])
    ret = PulseOutputs(
        root=execution.output_file("."),
        output_pulse_sequence_matrix=execution.output_file(output_base + "_pulsesequence_matrix"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PULSE_METADATA",
    "PulseOutputs",
    "pulse",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_4DFPTOANALYZE_METADATA = Metadata(
    id="65cd83dce834e4e472f7fa7af8e2201dfe71e3b3.boutiques",
    name="4dfptoanalyze",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class V4dfptoanalyzeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_4dfptoanalyze(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    analyze_hdr: OutputPathType
    """Header file of Analyze format output"""
    analyze_img: OutputPathType
    """Image file of Analyze format output"""


def v_4dfptoanalyze(
    input_file: InputPathType,
    scale_factor: float | None = None,
    output_8bit: bool = False,
    spm99: bool = False,
    endianness: str | None = None,
    runner: Runner | None = None,
) -> V4dfptoanalyzeOutputs:
    """
    Converts 4dfp formatted files to Analyze format.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input 4dfp filename.
        scale_factor: Scale output values by specified factor.
        output_8bit: Output 8 bit unsigned char.
        spm99: Include origin and scale in hdr.
        endianness: Output big or little endian (default CPU endian).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V4dfptoanalyzeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_4DFPTOANALYZE_METADATA)
    cargs = []
    cargs.append("4dfptoanalyze")
    cargs.append(execution.input_file(input_file))
    if scale_factor is not None:
        cargs.extend([
            "-c",
            str(scale_factor)
        ])
    if output_8bit:
        cargs.append("-8")
    if spm99:
        cargs.append("-SPM99")
    if endianness is not None:
        cargs.extend([
            "-@",
            endianness
        ])
    ret = V4dfptoanalyzeOutputs(
        root=execution.output_file("."),
        analyze_hdr=execution.output_file(pathlib.Path(input_file).name + "_analyze.hdr"),
        analyze_img=execution.output_file(pathlib.Path(input_file).name + "_analyze.img"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V4dfptoanalyzeOutputs",
    "V_4DFPTOANALYZE_METADATA",
    "v_4dfptoanalyze",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DSOUND_METADATA = Metadata(
    id="27afe9539a9fa717bc8a3162d9645362879cc57c.boutiques",
    name="1dsound",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dsoundOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1dsound(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """The output audio file."""


def v_1dsound(
    tsfile: InputPathType,
    prefix: str | None = None,
    encoding_16_pcm: bool = False,
    encoding_8_pcm: bool = False,
    encoding_8ulaw: bool = False,
    tper_option: float | None = None,
    fm_option: bool = False,
    notes_option: bool = False,
    notewave_option: str | None = None,
    despike_option: bool = False,
    play_option: bool = False,
    runner: Runner | None = None,
) -> V1dsoundOutputs:
    """
    Program to create a sound file from a 1D file (column of numbers).
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        tsfile: The input 1D time series file containing the data to transform\
            into sound.
        prefix: Prefix for the output filename, which will have '.au'\
            extension.
        encoding_16_pcm: Output in 16-bit linear PCM encoding (uncompressed).
        encoding_8_pcm: Output in 8-bit linear PCM encoding.
        encoding_8ulaw: Output in 8-bit mu-law encoding.
        tper_option: Time in seconds per time point in 'tsfile'. Allowed range\
            is 0.01 to 1.0 (inclusive). [default is 0.2s].
        fm_option: Output sound is frequency modulated between 110 and 1760 Hz\
            from min to max in the input 1D file.
        notes_option: Output sound is a sequence of notes, low to high pitch\
            based on min to max in the input 1D file. Uses pentatonic scale.
        notewave_option: Shape of the notes used. Select from [sine, sqsine,\
            square, triangle].
        despike_option: Apply a simple despiking algorithm to avoid artifacts\
            from large/small values in the input.
        play_option: Plays the sound file after it is written.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dsoundOutputs`).
    """
    if tper_option is not None and not (0.01 <= tper_option <= 1.0): 
        raise ValueError(f"'tper_option' must be between 0.01 <= x <= 1.0 but was {tper_option}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DSOUND_METADATA)
    cargs = []
    cargs.append("1dsound")
    cargs.append(execution.input_file(tsfile))
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if encoding_16_pcm:
        cargs.append("-16PCM")
    if encoding_8_pcm:
        cargs.append("-8PCM")
    if encoding_8ulaw:
        cargs.append("-8ulaw")
    if tper_option is not None:
        cargs.extend([
            "-tper",
            str(tper_option)
        ])
    if fm_option:
        cargs.append("-FM")
    if notes_option:
        cargs.append("-notes")
    if notewave_option is not None:
        cargs.extend([
            "-notewave",
            notewave_option
        ])
    if despike_option:
        cargs.append("-despike")
    if play_option:
        cargs.append("-play")
    ret = V1dsoundOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(prefix + ".au") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dsoundOutputs",
    "V_1DSOUND_METADATA",
    "v_1dsound",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_MATRIX_MULTIPLY_METADATA = Metadata(
    id="e27af9270450150cf8e376927c002e9ad9bce68e.boutiques",
    name="mri_matrix_multiply",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriMatrixMultiplyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_matrix_multiply(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_matrix_file: OutputPathType
    """Output matrix file resulting from the matrix multiplication."""


def mri_matrix_multiply(
    input_matrices: list[InputPathType],
    output_matrix: str,
    inverted_input_matrices: list[InputPathType] | None = None,
    verbose: bool = False,
    fsl: bool = False,
    binarize: bool = False,
    subject_name: str | None = None,
    runner: Runner | None = None,
) -> MriMatrixMultiplyOutputs:
    """
    Command-line tool for multiplying and manipulating MRI transformation matrices.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_matrices: Input matrix files for multiplication.
        output_matrix: Output matrix file.
        inverted_input_matrices: Input matrix files to be inverted before\
            multiplication.
        verbose: Verbose output.
        fsl: Assume input/output are FSL-style matrix files.
        binarize: 'Binarize' the output matrix.
        subject_name: Subject name for output reg.dat files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriMatrixMultiplyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_MATRIX_MULTIPLY_METADATA)
    cargs = []
    cargs.append("mri_matrix_multiply")
    cargs.extend([
        "-im",
        *[execution.input_file(f) for f in input_matrices]
    ])
    if inverted_input_matrices is not None:
        cargs.extend([
            "-iim",
            *[execution.input_file(f) for f in inverted_input_matrices]
        ])
    cargs.extend([
        "-om",
        output_matrix
    ])
    if verbose:
        cargs.append("-v")
    if fsl:
        cargs.append("-fsl")
    if binarize:
        cargs.append("-bin")
    if subject_name is not None:
        cargs.extend([
            "-s",
            subject_name
        ])
    ret = MriMatrixMultiplyOutputs(
        root=execution.output_file("."),
        output_matrix_file=execution.output_file(output_matrix),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_MATRIX_MULTIPLY_METADATA",
    "MriMatrixMultiplyOutputs",
    "mri_matrix_multiply",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLCREATEHD_METADATA = Metadata(
    id="a1f23fc21d5b4fa921d24d195e31f974c2ac59d1.boutiques",
    name="fslcreatehd",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslcreatehdOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslcreatehd(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_headerfile: OutputPathType
    """Generated NIfTI header file"""


def fslcreatehd(
    xsize: float,
    ysize: float,
    zsize: float,
    tsize: float,
    xvoxsize: float,
    yvoxsize: float,
    zvoxsize: float,
    tr: float,
    xorigin: float,
    yorigin: float,
    zorigin: float,
    datatype: float,
    headername: str,
    nifti_xml_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> FslcreatehdOutputs:
    """
    Tool to create a new NIfTI header.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        xsize: Size of the image in the x dimension.
        ysize: Size of the image in the y dimension.
        zsize: Size of the image in the z dimension.
        tsize: Size of the image in the t dimension (time).
        xvoxsize: Voxel size in the x dimension.
        yvoxsize: Voxel size in the y dimension.
        zvoxsize: Voxel size in the z dimension.
        tr: Repetition time (TR) of the image.
        xorigin: Origin of the image in the x dimension.
        yorigin: Origin of the image in the y dimension.
        zorigin: Origin of the image in the z dimension.
        datatype: Datatype of the image (2=char, 4=short, 8=int, 16=float,\
            64=double).
        headername: Name of the header file to be created.
        nifti_xml_file: NIfTI XML file describing the header configuration\
            (Mutually exclusive with other inputs).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslcreatehdOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLCREATEHD_METADATA)
    cargs = []
    cargs.append("fslcreatehd")
    cargs.append(str(xsize))
    cargs.append(str(ysize))
    cargs.append(str(zsize))
    cargs.append(str(tsize))
    cargs.append(str(xvoxsize))
    cargs.append(str(yvoxsize))
    cargs.append(str(zvoxsize))
    cargs.append(str(tr))
    cargs.append(str(xorigin))
    cargs.append(str(yorigin))
    cargs.append(str(zorigin))
    cargs.append(str(datatype))
    cargs.append(headername)
    if nifti_xml_file is not None:
        cargs.append(execution.input_file(nifti_xml_file))
    ret = FslcreatehdOutputs(
        root=execution.output_file("."),
        out_headerfile=execution.output_file(headername + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLCREATEHD_METADATA",
    "FslcreatehdOutputs",
    "fslcreatehd",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DCLUST_METADATA = Metadata(
    id="3ce8cefee5cef3ba7b1a972b0fcad6cd5a2fd94f.boutiques",
    name="3dclust",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dclustOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dclust(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    prefixed_output: OutputPathType | None
    """New dataset with clusters set to zero based on prefix."""
    ordered_mask_output: OutputPathType | None
    """Ordered mask dataset based on savemask prefix."""


def v_3dclust(
    datasets: list[InputPathType],
    rmm: float | None = None,
    vmul: float | None = None,
    nn1: bool = False,
    nn2: bool = False,
    nn3: bool = False,
    noabs: bool = False,
    summarize: bool = False,
    nosum: bool = False,
    verb: bool = False,
    oned_format: bool = False,
    no_oned_format: bool = False,
    quiet: bool = False,
    mni: bool = False,
    isovalue: bool = False,
    isomerge: bool = False,
    inmask: bool = False,
    prefix: str | None = None,
    savemask: str | None = None,
    binary: bool = False,
    runner: Runner | None = None,
) -> V3dclustOutputs:
    """
    Performs simple-minded cluster detection in 3D datasets.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        datasets: Input dataset(s). More than one allowed, but only the first\
            sub-brick of the dataset.
        rmm: Cluster connection radius in millimeters.
        vmul: Minimum cluster volume in micro-liters or minimum number of\
            voxels if negative.
        nn1: 1st nearest-neighbor clustering (faces touching).
        nn2: 2nd nearest-neighbor clustering (edges touching).
        nn3: 3rd nearest-neighbor clustering (corners touching).
        noabs: Use the signed voxel intensities for calculations.
        summarize: Write out only the total nonzero voxel count and volume for\
            each dataset.
        nosum: Suppress printout of the totals.
        verb: Print out a progress report to stderr as computations proceed.
        oned_format: Write output in 1D format (default).
        no_oned_format: Do not write output in 1D format.
        quiet: Suppress all non-essential output.
        mni: Transform output xyz-coordinates from TLRC to MNI space if the\
            input dataset has the +tlrc view.
        isovalue: Clusters will be formed only from contiguous voxels that also\
            have the same value.
        isomerge: Clusters will be formed from each distinct value in the\
            dataset; spatial contiguity will not be used.
        inmask: Use an internal mask from the dataset to eliminate voxels\
            before clustering.
        prefix: Write a new dataset that is a copy of the input, but with all\
            voxels not in a cluster set to zero; provide a prefix for the new\
            dataset.
        savemask: Write a new dataset that is an ordered mask where the largest\
            cluster is labeled '1', the next largest '2', and so forth.
        binary: Turn the output of '-savemask' into a binary (0 or 1) mask.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dclustOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DCLUST_METADATA)
    cargs = []
    cargs.append("3dclust")
    if rmm is not None:
        cargs.append(str(rmm))
    if vmul is not None:
        cargs.append(str(vmul))
    cargs.extend([execution.input_file(f) for f in datasets])
    if nn1:
        cargs.append("-NN1")
    if nn2:
        cargs.append("-NN2")
    if nn3:
        cargs.append("-NN3")
    if noabs:
        cargs.append("-noabs")
    if summarize:
        cargs.append("-summarize")
    if nosum:
        cargs.append("-nosum")
    if verb:
        cargs.append("-verb")
    if oned_format:
        cargs.append("-1Dformat")
    if no_oned_format:
        cargs.append("-no_1Dformat")
    if quiet:
        cargs.append("-quiet")
    if mni:
        cargs.append("-mni")
    if isovalue:
        cargs.append("-isovalue")
    if isomerge:
        cargs.append("-isomerge")
    if inmask:
        cargs.append("-inmask")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if savemask is not None:
        cargs.extend([
            "-savemask",
            savemask
        ])
    if binary:
        cargs.append("-binary")
    ret = V3dclustOutputs(
        root=execution.output_file("."),
        prefixed_output=execution.output_file(prefix + ".nii.gz") if (prefix is not None) else None,
        ordered_mask_output=execution.output_file(savemask + ".nii.gz") if (savemask is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dclustOutputs",
    "V_3DCLUST_METADATA",
    "v_3dclust",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DPLOT_METADATA = Metadata(
    id="8a73ee3a42ebaf653aef47adb6f3fa781e513997.boutiques",
    name="1dplot",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dplotOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1dplot(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_1dplot(
    tsfiles: list[InputPathType],
    install: bool = False,
    sep: bool = False,
    one: bool = False,
    sepscl: bool = False,
    noline: bool = False,
    noline_: bool = False,
    box: bool = False,
    hist: bool = False,
    norm2: bool = False,
    normx: bool = False,
    norm1: bool = False,
    demean: bool = False,
    x: InputPathType | None = None,
    xl10: InputPathType | None = None,
    dx: float | None = None,
    xzero: float | None = None,
    nopush: bool = False,
    ignore: float | None = None,
    use: float | None = None,
    xlabel: str | None = None,
    ylabel: str | None = None,
    plabel: str | None = None,
    title: str | None = None,
    wintitle: str | None = None,
    naked: bool = False,
    aspect: float | None = None,
    stdin: bool = False,
    ps: bool = False,
    jpg: str | None = None,
    jpeg: str | None = None,
    png: str | None = None,
    pnm: str | None = None,
    pngs: str | None = None,
    jpgs: str | None = None,
    jpegs: str | None = None,
    pnms: str | None = None,
    ytran: str | None = None,
    xtran: str | None = None,
    xaxis: str | None = None,
    yaxis: str | None = None,
    ynames: list[str] | None = None,
    volreg: bool = False,
    thick: bool = False,
    thick_: bool = False,
    dashed: str | None = None,
    setenv: str | None = None,
    censor_rgb: str | None = None,
    censor: InputPathType | None = None,
    censortr: list[str] | None = None,
    concat: InputPathType | None = None,
    rbox: str | None = None,
    rbox_: str | None = None,
    line: str | None = None,
    runner: Runner | None = None,
) -> V1dplotOutputs:
    """
    Graphs the columns of a *.1D time series file to the X11 screen, or to an image
    file (.jpg or .png).
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        tsfiles: Input time series files (*.1D) to be plotted.
        install: Install a new X11 colormap.
        sep: Plot each column in a separate sub-graph.
        one: Plot all columns together in one big graph.
        sepscl: Plot each column in a separate sub-graph and allow each\
            sub-graph to have a different y-scale. This option is meaningless with\
            -one!.
        noline: Same as -noline, but will not try to plot values outside the\
            rectangular box that contains the graph axes.
        noline_: Same as -noline, but will not try to plot values outside the\
            rectangular box that contains the graph axes.
        box: Plot a small 'box' at each data point.
        hist: Plot graphs in histogram style (i.e., vertical boxes).
        norm2: Independently scale each time series plotted to have L_2 norm =\
            1 (sum of squares).
        normx: Independently scale each time series plotted to have max\
            absolute value = 1 (L_infinity norm).
        norm1: Independently scale each time series plotted to have max sum of\
            absolute values = 1 (L_1 norm).
        demean: Remove the mean from each time series before normalizing.
        x: Use for X axis the data in a specified .1D file.
        xl10: Use log10 of the specified .1D file as the X axis.
        dx: Spacing between points on the x-axis.
        xzero: Initial x coordinate.
        nopush: Don't 'push' axes ranges outwards.
        ignore: Skip first 'nn' rows in the input file.
        use: Plot 'mm' points.
        xlabel: Put string 'aa' below the x-axis.
        ylabel: Put string 'aa' to the left of the y-axis.
        plabel: Put string 'pp' atop the plot.
        title: Same as -plabel, but only works with -ps/-png/-jpg/-pnm options.
        wintitle: Set string 'pp' as the title of the frame containing the\
            plot.
        naked: Do NOT plot axes or labels, just the graph(s).
        aspect: Set the width-to-height ratio of the plot region to 'A'.
        stdin: Don't read from tsfile; instead, read from stdin and plot it.
        ps: Don't draw plot in a window; instead, write it to stdout in\
            PostScript format.
        jpg: Render plot to JPEG image and save to a file named 'fname'.
        jpeg: Render plot to JPEG image and save to a file named 'fname'.
        png: Render plot to PNG image and save to a file named 'fname'.
        pnm: Render plot to PNM image and save to a file named 'fname'.
        pngs: Render plot to PNG image of specified size and save to a file\
            named 'fname'.
        jpgs: Render plot to JPEG image of specified size and save to a file\
            named 'fname'.
        jpegs: Render plot to JPEG image of specified size and save to a file\
            named 'fname'.
        pnms: Render plot to PNM image of specified size and save to a file\
            named 'fname'.
        ytran: Transform the data along the y-axis by applying the expression\
            to each input value.
        xtran: Transform the data along the x-axis by applying the expression\
            to each input value.
        xaxis: Set the x-axis to run from value 'b' to value 't', with 'n'\
            major divisions and 'm' minor tic marks per major division.
        yaxis: Set the y-axis to run from value 'b' to value 't', with 'n'\
            major divisions and 'm' minor tic marks per major division.
        ynames: Use the strings as labels to the right of the graphs,\
            corresponding to each input column.
        volreg: Makes the 'ynames' be the same as the 6 labels used in\
            plug_volreg for Roll, Pitch, Yaw, I-S, R-L, and A-P movements.
        thick: Twice the power of '-thick' at no extra cost!.
        thick_: Twice the power of '-thick' at no extra cost!.
        dashed: Plot dashed lines between data points using specified\
            colon-separated list of dash values (1: solid, 2: longer dashes, 3:\
            shorter dashes).
        setenv: Set environment variable 'name' to 'val' for this run of the\
            program only.
        censor_rgb: Set the color used for marking to a specified color.
        censor: Specify the filename of the censor .1D time series.
        censortr: Specify time indexes to be marked in the graph(s).
        concat: Specify the filename for the list of concatenated runs.
        rbox: Draw a rectangular box with one extra horizontal line.
        rbox_: Draw a rectangular box with one extra horizontal line.
        line: Draw one line segment.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dplotOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DPLOT_METADATA)
    cargs = []
    cargs.append("1dplot")
    cargs.extend([execution.input_file(f) for f in tsfiles])
    if install:
        cargs.append("-install")
    if sep:
        cargs.append("-sep")
    if one:
        cargs.append("-one")
    if sepscl:
        cargs.append("-sepscl")
    if noline:
        cargs.append("-NOLINE")
    if noline_:
        cargs.append("-NOLINE")
    if box:
        cargs.append("-box")
    if hist:
        cargs.append("-hist")
    if norm2:
        cargs.append("-norm2")
    if normx:
        cargs.append("-normx")
    if norm1:
        cargs.append("-norm1")
    if demean:
        cargs.append("-demean")
    if x is not None:
        cargs.extend([
            "-x",
            execution.input_file(x)
        ])
    if xl10 is not None:
        cargs.extend([
            "-xl10",
            execution.input_file(xl10)
        ])
    if dx is not None:
        cargs.extend([
            "-dx",
            str(dx)
        ])
    if xzero is not None:
        cargs.extend([
            "-xzero",
            str(xzero)
        ])
    if nopush:
        cargs.append("-nopush")
    if ignore is not None:
        cargs.extend([
            "-ignore",
            str(ignore)
        ])
    if use is not None:
        cargs.extend([
            "-use",
            str(use)
        ])
    if xlabel is not None:
        cargs.extend([
            "-xlabel",
            xlabel
        ])
    if ylabel is not None:
        cargs.extend([
            "-ylabel",
            ylabel
        ])
    if plabel is not None:
        cargs.extend([
            "-plabel",
            plabel
        ])
    if title is not None:
        cargs.extend([
            "-title",
            title
        ])
    if wintitle is not None:
        cargs.extend([
            "-wintitle",
            wintitle
        ])
    if naked:
        cargs.append("-naked")
    if aspect is not None:
        cargs.extend([
            "-aspect",
            str(aspect)
        ])
    if stdin:
        cargs.append("-stdin")
    if ps:
        cargs.append("-ps")
    if jpg is not None:
        cargs.extend([
            "-jpg",
            jpg
        ])
    if jpeg is not None:
        cargs.extend([
            "-jpeg",
            jpeg
        ])
    if png is not None:
        cargs.extend([
            "-png",
            png
        ])
    if pnm is not None:
        cargs.extend([
            "-pnm",
            pnm
        ])
    if pngs is not None:
        cargs.extend([
            "-pngs",
            pngs
        ])
    if jpgs is not None:
        cargs.extend([
            "-jpgs",
            jpgs
        ])
    if jpegs is not None:
        cargs.extend([
            "-jpegs",
            jpegs
        ])
    if pnms is not None:
        cargs.extend([
            "-pnms",
            pnms
        ])
    if ytran is not None:
        cargs.extend([
            "-ytran",
            ytran
        ])
    if xtran is not None:
        cargs.extend([
            "-xtran",
            xtran
        ])
    if xaxis is not None:
        cargs.extend([
            "-xaxis",
            xaxis
        ])
    if yaxis is not None:
        cargs.extend([
            "-yaxis",
            yaxis
        ])
    if ynames is not None:
        cargs.extend([
            "-ynames",
            *ynames
        ])
    if volreg:
        cargs.append("-volreg")
    if thick:
        cargs.append("-THICK")
    if thick_:
        cargs.append("-THICK")
    if dashed is not None:
        cargs.extend([
            "-dashed",
            dashed
        ])
    if setenv is not None:
        cargs.extend([
            "-D",
            setenv
        ])
    if censor_rgb is not None:
        cargs.extend([
            "-censor_RGB",
            censor_rgb
        ])
    if censor is not None:
        cargs.extend([
            "-censor",
            execution.input_file(censor)
        ])
    if censortr is not None:
        cargs.extend([
            "-CENSORTR",
            *censortr
        ])
    if concat is not None:
        cargs.extend([
            "-concat",
            execution.input_file(concat)
        ])
    if rbox is not None:
        cargs.extend([
            "-Rbox",
            rbox
        ])
    if rbox_ is not None:
        cargs.extend([
            "-Rbox",
            rbox_
        ])
    if line is not None:
        cargs.extend([
            "-line",
            line
        ])
    ret = V1dplotOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dplotOutputs",
    "V_1DPLOT_METADATA",
    "v_1dplot",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DTIFIT_METADATA = Metadata(
    id="dacf8e41c8fb8dc8737a88c2eb3ec2ff8cf64a28.boutiques",
    name="dtifit",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class DtifitOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dtifit(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    fa_output: OutputPathType
    """Fractional anisotropy output"""
    md_output: OutputPathType
    """Mean diffusivity output"""
    mo_output: OutputPathType
    """Mode of the anisotropy output"""
    l1_output: OutputPathType
    """1st eigenvalue output"""
    l2_output: OutputPathType
    """2nd eigenvalue output"""
    l3_output: OutputPathType
    """3rd eigenvalue output"""


def dtifit(
    data_file: InputPathType,
    output_basename: str,
    mask_file: InputPathType,
    bvec_file: InputPathType,
    bval_file: InputPathType,
    verbose_flag: bool = False,
    sse_flag: bool = False,
    wls_flag: bool = False,
    kurt_flag: bool = False,
    kurtdir_flag: bool = False,
    littlebit_flag: bool = False,
    save_tensor_flag: bool = False,
    zmin: float | None = None,
    zmax: float | None = None,
    ymin: float | None = None,
    ymax: float | None = None,
    xmin: float | None = None,
    xmax: float | None = None,
    gradnonlin_file: InputPathType | None = None,
    confound_regressors: InputPathType | None = None,
    runner: Runner | None = None,
) -> DtifitOutputs:
    """
    DTIFIT - Fit a diffusion tensor model at each voxel.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        data_file: DTI data file.
        output_basename: Output basename.
        mask_file: Bet binary mask file.
        bvec_file: B vectors file.
        bval_file: B values file.
        verbose_flag: Switch on diagnostic messages.
        sse_flag: Output sum of squared errors.
        wls_flag: Fit the tensor with weighted least squares.
        kurt_flag: Output mean kurtosis map (for multi-shell data).
        kurtdir_flag: Output maps of kurtosis along each eigenvector: K1, K2,\
            and K3 (for multi-shell data).
        littlebit_flag: Only process small area of brain.
        save_tensor_flag: Save the elements of the tensor.
        zmin: Minimum z.
        zmax: Maximum z.
        ymin: Minimum y.
        ymax: Maximum y.
        xmin: Minimum x.
        xmax: Maximum x.
        gradnonlin_file: Gradient Nonlinearity Tensor file.
        confound_regressors: Input confound regressors.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DtifitOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DTIFIT_METADATA)
    cargs = []
    cargs.append("dtifit")
    cargs.extend([
        "-k",
        execution.input_file(data_file)
    ])
    cargs.extend([
        "-o",
        output_basename
    ])
    cargs.extend([
        "-m",
        execution.input_file(mask_file)
    ])
    cargs.extend([
        "-r",
        execution.input_file(bvec_file)
    ])
    cargs.extend([
        "-b",
        execution.input_file(bval_file)
    ])
    if verbose_flag:
        cargs.append("-V")
    if sse_flag:
        cargs.append("--sse")
    if wls_flag:
        cargs.append("-w")
    if kurt_flag:
        cargs.append("--kurt")
    if kurtdir_flag:
        cargs.append("--kurtdir")
    if littlebit_flag:
        cargs.append("--littlebit")
    if save_tensor_flag:
        cargs.append("--save_tensor")
    if zmin is not None:
        cargs.extend([
            "-z",
            str(zmin)
        ])
    if zmax is not None:
        cargs.extend([
            "-Z",
            str(zmax)
        ])
    if ymin is not None:
        cargs.extend([
            "-y",
            str(ymin)
        ])
    if ymax is not None:
        cargs.extend([
            "-Y",
            str(ymax)
        ])
    if xmin is not None:
        cargs.extend([
            "-x",
            str(xmin)
        ])
    if xmax is not None:
        cargs.extend([
            "-X",
            str(xmax)
        ])
    if gradnonlin_file is not None:
        cargs.extend([
            "--gradnonlin",
            execution.input_file(gradnonlin_file)
        ])
    if confound_regressors is not None:
        cargs.extend([
            "--cni",
            execution.input_file(confound_regressors)
        ])
    ret = DtifitOutputs(
        root=execution.output_file("."),
        fa_output=execution.output_file(output_basename + "_FA.nii.gz"),
        md_output=execution.output_file(output_basename + "_MD.nii.gz"),
        mo_output=execution.output_file(output_basename + "_MO.nii.gz"),
        l1_output=execution.output_file(output_basename + "_L1.nii.gz"),
        l2_output=execution.output_file(output_basename + "_L2.nii.gz"),
        l3_output=execution.output_file(output_basename + "_L3.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DTIFIT_METADATA",
    "DtifitOutputs",
    "dtifit",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LABEL2SURF_METADATA = Metadata(
    id="cd63394affbc5928ed92ba87251a2f8b6f4f20e0.boutiques",
    name="label2surf",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class Label2surfOutputs(typing.NamedTuple):
    """
    Output object returned when calling `label2surf(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_surf: OutputPathType
    """Resulting output surface file"""


def label2surf(
    input_surface: InputPathType,
    output_surface: str,
    labels: InputPathType,
    verbose_flag: bool = False,
    help_flag: bool = False,
    runner: Runner | None = None,
) -> Label2surfOutputs:
    """
    Transform a group of labels into a surface.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_surface: Input surface file.
        output_surface: Output surface file.
        labels: ASCII list of label files.
        verbose_flag: Switch on diagnostic messages.
        help_flag: Display help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Label2surfOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABEL2SURF_METADATA)
    cargs = []
    cargs.append("label2surf")
    cargs.extend([
        "--surf",
        execution.input_file(input_surface)
    ])
    cargs.extend([
        "--out",
        output_surface
    ])
    cargs.extend([
        "--labels",
        execution.input_file(labels)
    ])
    if verbose_flag:
        cargs.append("--verbose")
    if help_flag:
        cargs.append("--help")
    ret = Label2surfOutputs(
        root=execution.output_file("."),
        out_surf=execution.output_file(output_surface),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LABEL2SURF_METADATA",
    "Label2surfOutputs",
    "label2surf",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAKE_CORTEX_LABEL_METADATA = Metadata(
    id="f144e3d1e0fdf022a6e2282c867ba8f46fafc1cb.boutiques",
    name="make_cortex_label",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MakeCortexLabelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `make_cortex_label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_label_file: OutputPathType | None
    """The output cortex label file."""


def make_cortex_label(
    subject: str,
    hemi: str | None = None,
    use_a2009s: bool = False,
    output_name: str | None = "cortex",
    runner: Runner | None = None,
) -> MakeCortexLabelOutputs:
    """
    A tool to create cortical labels.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: The subject for which the cortex label is to be created.
        hemi: The hemisphere(s) on which to operate. Default is both\
            hemispheres.
        use_a2009s: Use aparc.a2009 instead of aparc.
        output_name: Output name. The output will be ?h.outname.label. Default\
            is 'cortex'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MakeCortexLabelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAKE_CORTEX_LABEL_METADATA)
    cargs = []
    cargs.append("make_cortex_label")
    cargs.extend([
        "--s",
        subject
    ])
    if hemi is not None:
        cargs.extend([
            "--h",
            hemi
        ])
    if use_a2009s:
        cargs.append("--a2009s")
    if output_name is not None:
        cargs.extend([
            "--o",
            output_name
        ])
    ret = MakeCortexLabelOutputs(
        root=execution.output_file("."),
        output_label_file=execution.output_file("?h." + output_name + ".label") if (output_name is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAKE_CORTEX_LABEL_METADATA",
    "MakeCortexLabelOutputs",
    "make_cortex_label",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_VOL2LABEL_METADATA = Metadata(
    id="f532cfda1529b1b6a60e84bccee64a9686213a07.boutiques",
    name="mri_vol2label",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriVol2labelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_vol2label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_label_file: OutputPathType
    """Generated label file."""
    output_volume_file: OutputPathType | None
    """Generated label volume file."""


def mri_vol2label(
    input_: InputPathType,
    label_file: str,
    label_id: float | None = None,
    threshold: float | None = None,
    vol_file: str | None = None,
    surf_subject_hemi: str | None = None,
    surf_path: str | None = None,
    opt_params: str | None = None,
    remove_holes: bool = False,
    dilations: float | None = None,
    erosions: float | None = None,
    help_: bool = False,
    runner: Runner | None = None,
) -> MriVol2labelOutputs:
    """
    Converts values in a volume or surface overlay to a label using specified
    parameters.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_: Input volume or surface overlay.
        label_file: Name of output label file.
        label_id: Value to match in the input.
        threshold: Threshold the input to make label (i.e., input > threshold)\
            instead of using Label ID.
        vol_file: Write label volume in this file.
        surf_subject_hemi: Interpret input as surface overlay with the given\
            subject and hemisphere (optionally with surface).
        surf_path: Specify surface path instead of subject/hemi.
        opt_params: Treats input as a probability map. Format: target delta\
            valmap.
        remove_holes: Remove holes in label and islands (with --surf only).
        dilations: Dilate label (with --surf only).
        erosions: Erode label (with --surf only).
        help_: Print out help information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriVol2labelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_VOL2LABEL_METADATA)
    cargs = []
    cargs.append("mri_vol2label")
    cargs.extend([
        "--i",
        execution.input_file(input_)
    ])
    if label_id is not None:
        cargs.extend([
            "--id",
            str(label_id)
        ])
    if threshold is not None:
        cargs.extend([
            "--thresh",
            str(threshold)
        ])
    cargs.extend([
        "--l",
        label_file
    ])
    if vol_file is not None:
        cargs.extend([
            "--v",
            vol_file
        ])
    if surf_subject_hemi is not None:
        cargs.extend([
            "--surf",
            surf_subject_hemi
        ])
    if surf_path is not None:
        cargs.extend([
            "--surf-path",
            surf_path
        ])
    if opt_params is not None:
        cargs.extend([
            "--opt",
            opt_params
        ])
    if remove_holes:
        cargs.append("--remove-holes-islands")
    if dilations is not None:
        cargs.extend([
            "--dilate",
            str(dilations)
        ])
    if erosions is not None:
        cargs.extend([
            "--erode",
            str(erosions)
        ])
    if help_:
        cargs.append("--help")
    ret = MriVol2labelOutputs(
        root=execution.output_file("."),
        output_label_file=execution.output_file(label_file),
        output_volume_file=execution.output_file(vol_file) if (vol_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_VOL2LABEL_METADATA",
    "MriVol2labelOutputs",
    "mri_vol2label",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REGISTER_SUBJECT_METADATA = Metadata(
    id="6d8227c3473da4e1cbb185ea0b901094c92afc70.boutiques",
    name="register_subject",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RegisterSubjectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `register_subject(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    normalized_output: OutputPathType | None
    """Intensity normalized output volume."""
    transformed_fsamples: OutputPathType | None
    """Transformed control points."""


def register_subject(
    input_volume: InputPathType | None = None,
    mask_volume: InputPathType | None = None,
    control_points: str | None = None,
    output_directory: str | None = None,
    log_file: InputPathType | None = None,
    gca_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> RegisterSubjectOutputs:
    """
    Tool for registering brain MR volumes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume for registration (e.g., brain.mgz).
        mask_volume: MR volume used to mask input volume.
        control_points: Control points used for registration.
        output_directory: Directory to write output files (e.g., transformed\
            fsamples).
        log_file: Log file for recording registration results.
        gca_file: GCA file required for registration.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RegisterSubjectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REGISTER_SUBJECT_METADATA)
    cargs = []
    cargs.append("register_subject")
    if input_volume is not None:
        cargs.append(execution.input_file(input_volume))
    if mask_volume is not None:
        cargs.append(execution.input_file(mask_volume))
    if control_points is not None:
        cargs.append(control_points)
    if output_directory is not None:
        cargs.append(output_directory)
    if log_file is not None:
        cargs.append(execution.input_file(log_file))
    if gca_file is not None:
        cargs.append(execution.input_file(gca_file))
    ret = RegisterSubjectOutputs(
        root=execution.output_file("."),
        normalized_output=execution.output_file(output_directory + "/norm.mgz") if (output_directory is not None) else None,
        transformed_fsamples=execution.output_file(output_directory + "/fsamples") if (output_directory is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REGISTER_SUBJECT_METADATA",
    "RegisterSubjectOutputs",
    "register_subject",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TFILTER_METADATA = Metadata(
    id="4735e83a23f97826ec3c39f708b0bfaeaff9f5e9.boutiques",
    name="3dTfilter",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTfilterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_tfilter(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType
    """Filtered output dataset"""


def v_3d_tfilter(
    inputdataset: InputPathType,
    outputdataset: str,
    filters: list[str],
    runner: Runner | None = None,
) -> V3dTfilterOutputs:
    """
    3dTfilter filters the time series in each voxel according to the user-specified
    filter functions.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        inputdataset: Input dataset.
        outputdataset: Output dataset.
        filters: Filter function(s) to apply.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTfilterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TFILTER_METADATA)
    cargs = []
    cargs.append("3dTfilter")
    cargs.extend([
        "-input",
        execution.input_file(inputdataset)
    ])
    cargs.extend([
        "-prefix",
        outputdataset
    ])
    cargs.extend([
        "-filter",
        *filters
    ])
    ret = V3dTfilterOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file(outputdataset),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTfilterOutputs",
    "V_3D_TFILTER_METADATA",
    "v_3d_tfilter",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

XSANATREG_METADATA = Metadata(
    id="fa7d0e1f8dd94e54884aa8dac608dad32d5de507.boutiques",
    name="xsanatreg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class XsanatregOutputs(typing.NamedTuple):
    """
    Output object returned when calling `xsanatreg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def xsanatreg(
    src_cordir: str,
    targ_cordir: str,
    transform_file: str,
    temp_directory: str | None = None,
    source_minc: str | None = None,
    target_minc: str | None = None,
    no_cleanup: bool = False,
    version: bool = False,
    umask: str | None = None,
    runner: Runner | None = None,
) -> XsanatregOutputs:
    """
    A tool for registering source and target COR volumes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        src_cordir: Directory of source COR volume.
        targ_cordir: Directory of target COR volume.
        transform_file: File in which to store the transformation.
        temp_directory: Directory for temporary storage, defaults to /tmp.
        source_minc: File name for source minc, set automatically if not\
            specified.
        target_minc: File name for target minc, set automatically if not\
            specified.
        no_cleanup: Do not delete temporary minc files.
        version: Print version and exit.
        umask: Set file mode creation mask.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `XsanatregOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(XSANATREG_METADATA)
    cargs = []
    cargs.append("xsanatreg")
    cargs.extend([
        "-src",
        src_cordir
    ])
    cargs.extend([
        "-targ",
        targ_cordir
    ])
    cargs.extend([
        "-xfm",
        transform_file
    ])
    if temp_directory is not None:
        cargs.extend([
            "-tmpdir",
            temp_directory
        ])
    if source_minc is not None:
        cargs.extend([
            "-srcminc",
            source_minc
        ])
    if target_minc is not None:
        cargs.extend([
            "-targminc",
            target_minc
        ])
    if no_cleanup:
        cargs.append("-nocleanup")
    if version:
        cargs.append("-version")
    if umask is not None:
        cargs.extend([
            "-umask",
            umask
        ])
    ret = XsanatregOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "XSANATREG_METADATA",
    "XsanatregOutputs",
    "xsanatreg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RSFGEN_METADATA = Metadata(
    id="42de4c95300ddfa6a27f2ddbc5b6d9dc63cdd292.boutiques",
    name="RSFgen",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class RsfgenOutputs(typing.NamedTuple):
    """
    Output object returned when calling `rsfgen(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType | None
    """Output .1D stimulus function files prefixed with the provided output
    prefix."""


def rsfgen(
    length: int,
    num_experimental_conditions: int,
    block_length: str | None = None,
    random_seed: float | None = None,
    suppress_output_flag: bool = False,
    single_file_flag: bool = False,
    single_column_flag: bool = False,
    output_prefix: str | None = None,
    num_reps: str | None = None,
    permutation_seed: float | None = None,
    markov_file: InputPathType | None = None,
    prob_zero: float | None = None,
    input_table: InputPathType | None = None,
    runner: Runner | None = None,
) -> RsfgenOutputs:
    """
    Program to generate random stimulus functions.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        length: Length of time series.
        num_experimental_conditions: Number of input stimuli (experimental\
            conditions).
        block_length: Block length for stimulus. Must specify stimulus index\
            and length. Example: -nblock 1 5.
        random_seed: Random number seed.
        suppress_output_flag: Flag to suppress screen output.
        single_file_flag: Place stimulus functions into a single .1D file.
        single_column_flag: Write stimulus functions as a single column of\
            decimal integers.
        output_prefix: Prefix for output .1D stimulus functions.
        num_reps: Number of repetitions for stimulus.
        permutation_seed: Stim label permutation random number seed.
        markov_file: File containing the transition probability matrix.
        prob_zero: Probability of a zero (i.e., null) state (default: 0).
        input_table: Filename of column or table of numbers. All other input\
            options (except -seed and -prefix) are ignored with this option.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RsfgenOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RSFGEN_METADATA)
    cargs = []
    cargs.append("RSFgen")
    cargs.extend([
        "-nt",
        str(length)
    ])
    cargs.extend([
        "-num_stimts",
        str(num_experimental_conditions)
    ])
    if block_length is not None:
        cargs.extend([
            "-nblock",
            block_length
        ])
    if random_seed is not None:
        cargs.extend([
            "-seed",
            str(random_seed)
        ])
    if suppress_output_flag:
        cargs.append("-quiet")
    if single_file_flag:
        cargs.append("-one_file")
    if single_column_flag:
        cargs.append("-one_col")
    if output_prefix is not None:
        cargs.extend([
            "-prefix",
            output_prefix
        ])
    if num_reps is not None:
        cargs.extend([
            "-nreps",
            num_reps
        ])
    if permutation_seed is not None:
        cargs.extend([
            "-pseed",
            str(permutation_seed)
        ])
    if markov_file is not None:
        cargs.extend([
            "-markov",
            execution.input_file(markov_file)
        ])
    if prob_zero is not None:
        cargs.extend([
            "-pzero",
            str(prob_zero)
        ])
    if input_table is not None:
        cargs.extend([
            "-table",
            execution.input_file(input_table)
        ])
    ret = RsfgenOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file(output_prefix + "1.1D") if (output_prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RSFGEN_METADATA",
    "RsfgenOutputs",
    "rsfgen",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__REORDER_METADATA = Metadata(
    id="93af53020ee1088a33b0e58234dc8960b688e23e.boutiques",
    name="@Reorder",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VReorderOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__reorder(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType
    """Reordered output dataset"""


def v__reorder(
    input_dataset: InputPathType,
    mapfile: InputPathType,
    prefix: str,
    offset: float | None = None,
    save_work: bool = False,
    test: bool = False,
    runner: Runner | None = None,
) -> VReorderOutputs:
    """
    Reorder sub-bricks of a dataset based on event mapping. Works similarly to the
    Reorder plugin.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dataset: Input dataset to reorder (e.g. EPI+tlrc).
        mapfile: TR to event mapping file (e.g. events.txt).
        prefix: Prefix for the output dataset.
        offset: Offset mapfile TR indices by OFFSET (in TRs).
        save_work: Do not delete work directory (reorder.work.dir) at the end.
        test: Just report sub-bricks, do not create datasets.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VReorderOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__REORDER_METADATA)
    cargs = []
    cargs.append("@Reorder")
    cargs.append(execution.input_file(input_dataset))
    cargs.append(execution.input_file(mapfile))
    cargs.append(prefix)
    if offset is not None:
        cargs.extend([
            "-offset",
            str(offset)
        ])
    if save_work:
        cargs.append("-save_work")
    if test:
        cargs.append("-test")
    ret = VReorderOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file(prefix + "+tlrc"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VReorderOutputs",
    "V__REORDER_METADATA",
    "v__reorder",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIRST_MULT_BCORR_METADATA = Metadata(
    id="a7d6c8e2e8974e5facac9a650b214397ba549860.boutiques",
    name="first_mult_bcorr",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FirstMultBcorrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `first_mult_bcorr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output image name (3D label image)"""


def first_mult_bcorr(
    input_image: InputPathType,
    corrected_4d_labels: InputPathType,
    uncorrected_4d_labels: InputPathType,
    output_image: str,
    verbose_flag: bool = False,
    runner: Runner | None = None,
) -> FirstMultBcorrOutputs:
    """
    Part of FSL (ID: 6.0.5:9e026117), first_mult_bcorr converts label images to an
    output image.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_image: Filename of original T1 input image.
        corrected_4d_labels: Filename of 4D image of individually corrected\
            labels.
        uncorrected_4d_labels: Filename of 4D image of uncorrected labels (with\
            boundaries).
        output_image: Output image name (3D label image).
        verbose_flag: Output F-stats to standard out.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FirstMultBcorrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIRST_MULT_BCORR_METADATA)
    cargs = []
    cargs.append("first_mult_bcorr")
    cargs.extend([
        "-i",
        execution.input_file(input_image)
    ])
    cargs.extend([
        "-c",
        execution.input_file(corrected_4d_labels)
    ])
    cargs.extend([
        "-u",
        execution.input_file(uncorrected_4d_labels)
    ])
    cargs.extend([
        "-o",
        output_image
    ])
    if verbose_flag:
        cargs.append("-v")
    ret = FirstMultBcorrOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_image),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIRST_MULT_BCORR_METADATA",
    "FirstMultBcorrOutputs",
    "first_mult_bcorr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF_DSET_INFO_METADATA = Metadata(
    id="0eea0d47be8d446fa32a71638d9796998abd8047.boutiques",
    name="SurfDsetInfo",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfDsetInfoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf_dset_info(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def surf_dset_info(
    input_dsets: list[InputPathType],
    debug_level: int | None = None,
    novolreg: bool = False,
    noxform: bool = False,
    setenv: str | None = None,
    trace_: bool = False,
    extreme_trace: bool = False,
    nomall: bool = False,
    yesmall: bool = False,
    mini_help: bool = False,
    help_: bool = False,
    extreme_help: bool = False,
    help_view: bool = False,
    help_web: bool = False,
    help_find: str | None = None,
    help_raw: bool = False,
    help_spx: bool = False,
    help_aspx: bool = False,
    all_opts: bool = False,
    runner: Runner | None = None,
) -> SurfDsetInfoOutputs:
    """
    Provides information about surface datasets (DSET).
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dsets: Input dataset.
        debug_level: Debug level. If DBG = 2, show full dataset information in\
            NIML form.
        novolreg: Ignore any Rotate, Volreg, Tagalign, or WarpDrive\
            transformations.
        noxform: Same as -novolreg.
        setenv: Set environment variable.
        trace_: Turns on In/Out debug and Memory tracing.
        extreme_trace: Turns on extreme tracing.
        nomall: Turn off memory tracing.
        yesmall: Turn on memory tracing (default).
        mini_help: Mini help.
        help_: Show entire help output.
        extreme_help: Show extreme help.
        help_view: Open help in text editor.
        help_web: Open help in web browser.
        help_find: Look for lines in help output that match the specified word.
        help_raw: Show unedited help string.
        help_spx: Show help string in sphinx format, but do not autoformat.
        help_aspx: Show help string in sphinx with autoformatting.
        all_opts: Attempt to identify all options for the program from the help\
            output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfDsetInfoOutputs`).
    """
    if debug_level is not None and not (0 <= debug_level): 
        raise ValueError(f"'debug_level' must be greater than 0 <= x but was {debug_level}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF_DSET_INFO_METADATA)
    cargs = []
    cargs.append("SurfDsetInfo")
    cargs.extend([
        "-input",
        *[execution.input_file(f) for f in input_dsets]
    ])
    if debug_level is not None:
        cargs.extend([
            "-debug",
            str(debug_level)
        ])
    if novolreg:
        cargs.append("-novolreg")
    if noxform:
        cargs.append("-noxform")
    if setenv is not None:
        cargs.extend([
            "-setenv",
            setenv
        ])
    if trace_:
        cargs.append("-trace")
    if extreme_trace:
        cargs.append("-TRACE")
    if nomall:
        cargs.append("-nomall")
    if yesmall:
        cargs.append("-yesmall")
    if mini_help:
        cargs.append("-h")
    if help_:
        cargs.append("-help")
    if extreme_help:
        cargs.append("-HELP")
    if help_view:
        cargs.append("-h_view")
    if help_web:
        cargs.append("-h_web")
    if help_find is not None:
        cargs.extend([
            "-h_find",
            help_find
        ])
    if help_raw:
        cargs.append("-h_raw")
    if help_spx:
        cargs.append("-h_spx")
    if help_aspx:
        cargs.append("-h_aspx")
    if all_opts:
        cargs.append("-all_opts")
    ret = SurfDsetInfoOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF_DSET_INFO_METADATA",
    "SurfDsetInfoOutputs",
    "surf_dset_info",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_SPAT_NORM_METADATA = Metadata(
    id="3dfa068ac2f6a03026257ba621a4c3d853de135b.boutiques",
    name="3dSpatNorm",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dSpatNormOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_spat_norm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_head: OutputPathType | None
    """Output dataset (HEAD file)"""
    out_brik: OutputPathType | None
    """Output dataset (BRIK file)"""


def v_3d_spat_norm(
    dataset: InputPathType,
    prefix: str | None = None,
    orig_space: bool = False,
    verbose: bool = False,
    monkey: bool = False,
    marmot: bool = False,
    rat: bool = False,
    human: bool = False,
    bottom_cuts: str | None = None,
    runner: Runner | None = None,
) -> V3dSpatNormOutputs:
    """
    An obsolete tool for spatial normalization.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dataset: Input dataset.
        prefix: Write output dataset using 'ppp' for the prefix.
        orig_space: Write output dataset using the same grid as dataset.
        verbose: Write out progress reports.
        monkey: Monkey business.
        marmot: Marmoset head.
        rat: Rat head.
        human: Bone head (default).
        bottom_cuts: Make approximate cuts at the bottom to shave non-brain\
            areas. CUTFLAGS is a string of characters indicating which sides to\
            cut: 'A' for anterior, 'P' for posterior, 'R' for right, 'L' for left.\
            Example: -bottom_cuts APLR.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dSpatNormOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_SPAT_NORM_METADATA)
    cargs = []
    cargs.append("3dSpatNorm")
    cargs.append(execution.input_file(dataset))
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if orig_space:
        cargs.append("-orig_space")
    if verbose:
        cargs.append("-verb")
    if monkey:
        cargs.append("-monkey")
    if marmot:
        cargs.append("-marmost")
    if rat:
        cargs.append("-rat")
    if human:
        cargs.append("-human")
    if bottom_cuts is not None:
        cargs.extend([
            "-bottom_cuts",
            bottom_cuts
        ])
    ret = V3dSpatNormOutputs(
        root=execution.output_file("."),
        out_head=execution.output_file(prefix + "+orig.HEAD") if (prefix is not None) else None,
        out_brik=execution.output_file(prefix + "+orig.BRIK") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dSpatNormOutputs",
    "V_3D_SPAT_NORM_METADATA",
    "v_3d_spat_norm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_LOCAL_UNIFIZE_METADATA = Metadata(
    id="15f1fc4af844d2f3848e6e3527f1534179ded986.boutiques",
    name="3dLocalUnifize",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dLocalUnifizeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_local_unifize(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output dataset file"""


def v_3d_local_unifize(
    input_: InputPathType,
    output: str,
    working_dir: str | None = None,
    echo: bool = False,
    no_clean: bool = False,
    local_rad: float | None = None,
    local_perc: float | None = None,
    local_mask: str | None = None,
    filter_thr: float | None = None,
    runner: Runner | None = None,
) -> V3dLocalUnifizeOutputs:
    """
    This program generates a 'unifized' output volume by estimating the median in
    the local neighborhood of each voxel and using that to scale each voxel's
    brightness.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_: Input dataset.
        output: Output dataset name, including path.
        working_dir: Name of temporary working directory (def:\
            __wdir_LocalUni_, plus a random alphanumeric str).
        echo: Run this program very verbosely (default: false).
        no_clean: Do not remove the working directory (default: remove it).
        local_rad: The spherical neighborhood's radius for the 3dLocalStat step\
            (default: -3).
        local_perc: The percentile used in the 3dLocalStat step, generating the\
            scaling volume (default: 50).
        local_mask: Provide the masking option for the 3dLocalStat step; to\
            remove any masking, put 'None' as the option value (default:\
            "-automask").
        filter_thr: Ceiling on values in the final, scaled dataset; values <=0\
            turn off this final filtering (default: 1.5).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dLocalUnifizeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_LOCAL_UNIFIZE_METADATA)
    cargs = []
    cargs.append("3dLocalUnifize")
    cargs.append(execution.input_file(input_))
    cargs.extend([
        "-prefix",
        output
    ])
    if working_dir is not None:
        cargs.extend([
            "-wdir_name",
            working_dir
        ])
    if echo:
        cargs.append("-echo")
    if no_clean:
        cargs.append("-no_clean")
    if local_rad is not None:
        cargs.extend([
            "-local_rad",
            str(local_rad)
        ])
    if local_perc is not None:
        cargs.extend([
            "-local_perc",
            str(local_perc)
        ])
    if local_mask is not None:
        cargs.extend([
            "-local_mask",
            local_mask
        ])
    if filter_thr is not None:
        cargs.extend([
            "-filter_thr",
            str(filter_thr)
        ])
    ret = V3dLocalUnifizeOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dLocalUnifizeOutputs",
    "V_3D_LOCAL_UNIFIZE_METADATA",
    "v_3d_local_unifize",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_PREPROC_METADATA = Metadata(
    id="dd5edb4541571b929ce3905d2cb09807c8f4d850.boutiques",
    name="mris_preproc",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisPreprocOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_preproc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_preproc(
    outfile: str,
    target_subject: str,
    hemi: str,
    meas: str | None = None,
    label: str | None = None,
    measdir: str | None = None,
    subjects: list[str] | None = None,
    fsgd: InputPathType | None = None,
    subjectlist: InputPathType | None = None,
    qdec: InputPathType | None = None,
    qdec_long: InputPathType | None = None,
    surfmeasfile: list[InputPathType] | None = None,
    projfrac: float | None = None,
    projfrac_max: list[float] | None = None,
    projfrac_avg: list[float] | None = None,
    no_mask_non_cortex: bool = False,
    session_file: InputPathType | None = None,
    dir_file: InputPathType | None = None,
    analysis: str | None = None,
    contrast: str | None = None,
    cvar_flag: bool = False,
    offset_flag: bool = False,
    map_: str | None = None,
    etiv_flag: bool = False,
    fwhm: float | None = None,
    fwhm_src: float | None = None,
    niters: float | None = None,
    niters_src: float | None = None,
    cortex_only: bool = False,
    mgz_flag: bool = False,
    no_jac_flag: bool = False,
    paired_diff_flag: bool = False,
    cache_out: str | None = None,
    cache_in: str | None = None,
    cache_out_only: str | None = None,
    no_prune_flag: bool = False,
    mean_flag: bool = False,
    std_flag: bool = False,
    reshape_flag: bool = False,
    surfreg: str | None = None,
    subjects_dir: str | None = None,
    synth_flag: bool = False,
    tmpdir: str | None = None,
    nocleanup_flag: bool = False,
    cleanup_flag: bool = False,
    log: str | None = None,
    nolog_flag: bool = False,
    debug_flag: bool = False,
    runner: Runner | None = None,
) -> MrisPreprocOutputs:
    """
    Script to prepare surface-based data for high-level analysis by resampling
    surface or volume source data to a common subject and concatenating them into
    one file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        outfile: Save output here.
        target_subject: Subject to use as the common-space. All input data will\
            be resampled to the surface of this subject.
        hemi: Use hemisphere for source and target surfaces. Can be lh or rh.
        meas: Use subject/surf/hemi.surfmeasure as input. Implies --srcfmt\
            curv.
        label: Look in label/hemi.annotname.(annot,mgz) and use mapmethod nnf.
        measdir: Look in subdir instead of surf.
        subjects: Specify an input subject on the command-line. All subjects\
            must be specified in this way.
        fsgd: Specify the list of input subjects from the fsgd file.
        subjectlist: List all subjects separated by white space in\
            subjlistfile.
        qdec: Specify list of subjects via qdec table file. Assumes the first\
            column is the "fsid".
        qdec_long: Specify list of subjects via longitudinal qdec table file.
        surfmeasfile: Specify full path to input surface measure file.
        projfrac: When sampling a volume onto the surface, sample a fraction of\
            the thickness along the surface normal.
        projfrac_max: When sampling a volume onto the surface, find max along\
            projection for vol2surf.
        projfrac_avg: Compute average along projection for vol2surf.
        no_mask_non_cortex: Do not mask out non-cortex in vol2surf.
        session_file: FS-FAST session file.
        dir_file: FS-FAST session directory file.
        analysis: FS-FAST analysis.
        contrast: FS-FAST contrast.
        cvar_flag: Use fsfast contrast variance (cesvar).
        offset_flag: Use fsfast mean offset (h-offset).
        map_: Use fsfast contrast/map.
        etiv_flag: Divide each subject's value by the Estimated Total Intra\
            Cranial Volume as found in aseg.stats.
        fwhm: Smooth by fwhm mm on the target surface.
        fwhm_src: Smooth by fwhm mm on the source surface.
        niters: Smooth by niters on the target surface.
        niters_src: Smooth by niters on the source surface.
        cortex_only: Exclude medial wall.
        mgz_flag: Use mgz format internally.
        no_jac_flag: Turn off jacobian correction.
        paired_diff_flag: Compute paired differences after concatenating all\
            inputs together.
        cache_out: Cache the output in the specified cache file.
        cache_in: Use the pre-computed cached data from the specified cache\
            file.
        cache_out_only: Cache data without actually creating an output.
        no_prune_flag: Do not prune the inputs.
        mean_flag: Compute the mean of all inputs.
        std_flag: Compute the standard deviation of all inputs.
        reshape_flag: Reshape spatial dimensions.
        surfreg: Use specified surface registration to the common space.
        subjects_dir: Set SUBJECTS_DIR environment variable.
        synth_flag: Synthesize the input data with white gaussian noise.
        tmpdir: Use specified temporary directory.
        nocleanup_flag: Do not delete temporary files.
        cleanup_flag: Delete temporary files (default).
        log: Specify log file.
        nolog_flag: Do not create a log file.
        debug_flag: Enable debug mode.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisPreprocOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_PREPROC_METADATA)
    cargs = []
    cargs.append("mris_preproc")
    cargs.extend([
        "--out",
        outfile
    ])
    cargs.extend([
        "--target",
        target_subject
    ])
    cargs.extend([
        "--hemi",
        hemi
    ])
    if meas is not None:
        cargs.extend([
            "--meas",
            meas
        ])
    if label is not None:
        cargs.extend([
            "--label",
            label
        ])
    if measdir is not None:
        cargs.extend([
            "--measdir",
            measdir
        ])
    if subjects is not None:
        cargs.extend([
            "--s",
            *subjects
        ])
    if fsgd is not None:
        cargs.extend([
            "--fsgd",
            execution.input_file(fsgd)
        ])
    if subjectlist is not None:
        cargs.extend([
            "--f",
            execution.input_file(subjectlist)
        ])
    if qdec is not None:
        cargs.extend([
            "--qdec",
            execution.input_file(qdec)
        ])
    if qdec_long is not None:
        cargs.extend([
            "--qdec-long",
            execution.input_file(qdec_long)
        ])
    if surfmeasfile is not None:
        cargs.extend([
            "--is",
            *[execution.input_file(f) for f in surfmeasfile]
        ])
    cargs.append("[VOLMEASFILE]")
    if projfrac is not None:
        cargs.extend([
            "--projfrac",
            str(projfrac)
        ])
    if projfrac_max is not None:
        cargs.extend([
            "--projfrac-max",
            *map(str, projfrac_max)
        ])
    if projfrac_avg is not None:
        cargs.extend([
            "--projfrac-avg",
            *map(str, projfrac_avg)
        ])
    if no_mask_non_cortex:
        cargs.append("--no-mask-non-cortex")
    if session_file is not None:
        cargs.extend([
            "--sf",
            execution.input_file(session_file)
        ])
    if dir_file is not None:
        cargs.extend([
            "--df",
            execution.input_file(dir_file)
        ])
    if analysis is not None:
        cargs.extend([
            "--analysis",
            analysis
        ])
    if contrast is not None:
        cargs.extend([
            "--contrast",
            contrast
        ])
    if cvar_flag:
        cargs.append("--cvar")
    if offset_flag:
        cargs.append("--offset")
    if map_ is not None:
        cargs.extend([
            "--map",
            map_
        ])
    if etiv_flag:
        cargs.append("--etiv")
    if fwhm is not None:
        cargs.extend([
            "--fwhm",
            str(fwhm)
        ])
    if fwhm_src is not None:
        cargs.extend([
            "--fwhm-src",
            str(fwhm_src)
        ])
    if niters is not None:
        cargs.extend([
            "--niters",
            str(niters)
        ])
    if niters_src is not None:
        cargs.extend([
            "--niters-src",
            str(niters_src)
        ])
    if cortex_only:
        cargs.append("--cortex-only")
    if mgz_flag:
        cargs.append("--mgz")
    if no_jac_flag:
        cargs.append("--no-jac")
    if paired_diff_flag:
        cargs.append("--paired-diff")
    if cache_out is not None:
        cargs.extend([
            "--cache-out",
            cache_out
        ])
    if cache_in is not None:
        cargs.extend([
            "--cache-in",
            cache_in
        ])
    if cache_out_only is not None:
        cargs.extend([
            "--cache-out-only",
            cache_out_only
        ])
    if no_prune_flag:
        cargs.append("--no-prune")
    if mean_flag:
        cargs.append("--mean")
    if std_flag:
        cargs.append("--std")
    if reshape_flag:
        cargs.append("--reshape")
    if surfreg is not None:
        cargs.extend([
            "--surfreg",
            surfreg
        ])
    if subjects_dir is not None:
        cargs.extend([
            "--SUBJECTS_DIR",
            subjects_dir
        ])
    if synth_flag:
        cargs.append("--synth")
    if tmpdir is not None:
        cargs.extend([
            "--tmpdir",
            tmpdir
        ])
    if nocleanup_flag:
        cargs.append("--nocleanup")
    if cleanup_flag:
        cargs.append("--cleanup")
    if log is not None:
        cargs.extend([
            "--log",
            log
        ])
    if nolog_flag:
        cargs.append("--nolog")
    if debug_flag:
        cargs.append("--debug")
    ret = MrisPreprocOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_PREPROC_METADATA",
    "MrisPreprocOutputs",
    "mris_preproc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRMATH_METADATA = Metadata(
    id="51b59bbaad9ca5110175fd6f6f0765499d38c928.boutiques",
    name="mrmath",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class MrmathConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class MrmathOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mrmath(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """the output image."""


def mrmath(
    input_: list[InputPathType],
    operation: str,
    output: str,
    axis: int | None = None,
    keep_unary_axes: bool = False,
    datatype: str | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[MrmathConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MrmathOutputs:
    """
    Compute summary statistic on image intensities either across images, or along a
    specified axis of a single image.
    
    Supported operations are:
    
    mean, median, sum, product, rms (root-mean-square value), norm (vector
    2-norm), var (unbiased variance), std (unbiased standard deviation), min,
    max, absmax (maximum absolute value), magmax (value with maximum absolute
    value, preserving its sign).
    
    This command is used to traverse either along an image axis, or across a set
    of input images, calculating some statistic from the values along each
    traversal. If you are seeking to instead perform mathematical calculations
    that are done independently for each voxel, pleaase see the 'mrcalc'
    command.
    
    References:
    
    .
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        input_: the input image(s).
        operation: the operation to apply, one of: mean, median, sum, product,\
            rms, norm, var, std, min, max, absmax, magmax.
        output: the output image.
        axis: perform operation along a specified axis of a single input image.
        keep_unary_axes: Keep unary axes in input images prior to calculating\
            the stats. The default is to wipe axes with single elements.
        datatype: specify output image data type. Valid choices are: float32,\
            float32le, float32be, float64, float64le, float64be, int64, uint64,\
            int64le, uint64le, int64be, uint64be, int32, uint32, int32le, uint32le,\
            int32be, uint32be, int16, uint16, int16le, uint16le, int16be, uint16be,\
            cfloat32, cfloat32le, cfloat32be, cfloat64, cfloat64le, cfloat64be,\
            int8, uint8, bit.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrmathOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRMATH_METADATA)
    cargs = []
    cargs.append("mrmath")
    if axis is not None:
        cargs.extend([
            "-axis",
            str(axis)
        ])
    if keep_unary_axes:
        cargs.append("-keep_unary_axes")
    if datatype is not None:
        cargs.extend([
            "-datatype",
            datatype
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.extend([execution.input_file(f) for f in input_])
    cargs.append(operation)
    cargs.append(output)
    ret = MrmathOutputs(
        root=execution.output_file("."),
        output=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRMATH_METADATA",
    "MrmathConfig",
    "MrmathOutputs",
    "mrmath",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REGISTER_SUBJECT_FLASH_METADATA = Metadata(
    id="9a7a639d778167b266b2e9f5c9a4ba404e0ced41.boutiques",
    name="register_subject_flash",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RegisterSubjectFlashOutputs(typing.NamedTuple):
    """
    Output object returned when calling `register_subject_flash(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    log_file: OutputPathType
    """Log file output with registration results."""


def register_subject_flash(
    input_volumes: list[InputPathType],
    runner: Runner | None = None,
) -> RegisterSubjectFlashOutputs:
    """
    Register subject using the FLASH forward model to predict intensity values.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volumes: Input volumes to register.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RegisterSubjectFlashOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REGISTER_SUBJECT_FLASH_METADATA)
    cargs = []
    cargs.append("register_subject_flash")
    cargs.extend([execution.input_file(f) for f in input_volumes])
    ret = RegisterSubjectFlashOutputs(
        root=execution.output_file("."),
        log_file=execution.output_file("talairach.log"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REGISTER_SUBJECT_FLASH_METADATA",
    "RegisterSubjectFlashOutputs",
    "register_subject_flash",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_INTERPOLATE_WARP_METADATA = Metadata(
    id="4c3b574c8d475695ef29da0c89214dc574282c1e.boutiques",
    name="mris_interpolate_warp",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisInterpolateWarpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_interpolate_warp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_interpolate_warp(
    start_surface: InputPathType,
    end_surface: InputPathType,
    warp_field: InputPathType,
    runner: Runner | None = None,
) -> MrisInterpolateWarpOutputs:
    """
    Interpolate warp on cortical surfaces.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        start_surface: The starting surface file.
        end_surface: The ending surface file.
        warp_field: The warp field file with .m3z extension.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisInterpolateWarpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_INTERPOLATE_WARP_METADATA)
    cargs = []
    cargs.append("mris_interpolate_warp")
    cargs.append(execution.input_file(start_surface))
    cargs.append(execution.input_file(end_surface))
    cargs.append(execution.input_file(warp_field))
    ret = MrisInterpolateWarpOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_INTERPOLATE_WARP_METADATA",
    "MrisInterpolateWarpOutputs",
    "mris_interpolate_warp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DISTANCEMAP_METADATA = Metadata(
    id="76f81ca05221fbcd3ffc81e3e036b1d68137e2bd.boutiques",
    name="distancemap",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class DistancemapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `distancemap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_distancemap: OutputPathType
    """Output distance map image"""
    output_local_maxima: OutputPathType | None
    """Output local maxima image"""
    output_segmented_image: OutputPathType | None
    """Output segmented distance map image"""


def distancemap(
    input_image: InputPathType,
    output_image: InputPathType,
    mask_image: InputPathType | None = None,
    second_image: InputPathType | None = None,
    local_maxima_image: InputPathType | None = None,
    segmented_image: InputPathType | None = None,
    invert_flag: bool = False,
    interpolate_values: InputPathType | None = None,
    verbose_flag: bool = False,
    help_flag: bool = False,
    runner: Runner | None = None,
) -> DistancemapOutputs:
    """
    A tool to calculate distance maps using FSL.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_image: Input image filename (calc distance to non-zero voxels).
        output_image: Output image filename.
        mask_image: Mask image filename (only calc values at these voxels).
        second_image: Second image filename (calc closest distance of this and\
            primary input image, using non-zero voxels, negative distances mean\
            this secondary image is the closer one).
        local_maxima_image: Local maxima output image filename.
        segmented_image: Segmented output image filename (unique value per\
            segment is local maxima label).
        invert_flag: Invert input image.
        interpolate_values: Filename for values to interpolate (sparse sampling\
            interpolation).
        verbose_flag: Switch on diagnostic messages.
        help_flag: Display help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DistancemapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DISTANCEMAP_METADATA)
    cargs = []
    cargs.append("distancemap")
    cargs.extend([
        "-i",
        execution.input_file(input_image)
    ])
    cargs.extend([
        "-o",
        execution.input_file(output_image)
    ])
    if mask_image is not None:
        cargs.extend([
            "-m",
            execution.input_file(mask_image)
        ])
    if second_image is not None:
        cargs.extend([
            "--secondim",
            execution.input_file(second_image)
        ])
    if local_maxima_image is not None:
        cargs.extend([
            "-l",
            execution.input_file(local_maxima_image)
        ])
    if segmented_image is not None:
        cargs.extend([
            "-s",
            execution.input_file(segmented_image)
        ])
    if invert_flag:
        cargs.append("--invert")
    if interpolate_values is not None:
        cargs.extend([
            "--interp",
            execution.input_file(interpolate_values)
        ])
    if verbose_flag:
        cargs.append("-v")
    if help_flag:
        cargs.append("-h")
    ret = DistancemapOutputs(
        root=execution.output_file("."),
        output_distancemap=execution.output_file(pathlib.Path(output_image).name),
        output_local_maxima=execution.output_file(pathlib.Path(local_maxima_image).name) if (local_maxima_image is not None) else None,
        output_segmented_image=execution.output_file(pathlib.Path(segmented_image).name) if (segmented_image is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DISTANCEMAP_METADATA",
    "DistancemapOutputs",
    "distancemap",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BEDPOSTX_MGH_METADATA = Metadata(
    id="fb49a4fd21cd6f6cf877e9365ca0aa77e9e1a7f5.boutiques",
    name="bedpostx_mgh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class BedpostxMghOutputs(typing.NamedTuple):
    """
    Output object returned when calling `bedpostx_mgh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def bedpostx_mgh(
    subject_directory: str,
    fibres: float | None = None,
    ard_weight: float | None = None,
    burnin: float | None = None,
    jumps: float | None = None,
    sample_every: float | None = None,
    deconv_model: float | None = None,
    gradient_nonlin: bool = False,
    runner: Runner | None = None,
) -> BedpostxMghOutputs:
    """
    A modified version of FSL's bedpostx compatible with PBS queueing system for
    parallel computation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_directory: Subject directory containing necessary files such as\
            bvals, bvecs, data, and nodif_brain_mask.
        fibres: Number of fibres per voxel, default is 3.
        ard_weight: ARD weight, more weight means fewer secondary fibres per\
            voxel, default is 1.
        burnin: Burnin period, default is 1000.
        jumps: Number of jumps, default is 1250.
        sample_every: Sample every n steps, default is 25.
        deconv_model: Deconvolution model selection. 1: with sticks, 2: with\
            sticks with a range of diffusivities (default), 3: with zeppelins.
        gradient_nonlin: Consider gradient nonlinearities, default is off.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BedpostxMghOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BEDPOSTX_MGH_METADATA)
    cargs = []
    cargs.append("bedpostx_mgh")
    cargs.append(subject_directory)
    if fibres is not None:
        cargs.extend([
            "-n",
            str(fibres)
        ])
    if ard_weight is not None:
        cargs.extend([
            "-w",
            str(ard_weight)
        ])
    if burnin is not None:
        cargs.extend([
            "-b",
            str(burnin)
        ])
    if jumps is not None:
        cargs.extend([
            "-j",
            str(jumps)
        ])
    if sample_every is not None:
        cargs.extend([
            "-s",
            str(sample_every)
        ])
    if deconv_model is not None:
        cargs.extend([
            "-model",
            str(deconv_model)
        ])
    if gradient_nonlin:
        cargs.append("-g")
    ret = BedpostxMghOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BEDPOSTX_MGH_METADATA",
    "BedpostxMghOutputs",
    "bedpostx_mgh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__ALIGN_CENTERS_METADATA = Metadata(
    id="f29fbec7d33b88a11144d9ab1edf49dc32ae31cf.boutiques",
    name="@Align_Centers",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VAlignCentersOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__align_centers(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    transform_matrix: OutputPathType
    """Transform matrix needed for the shift applied to DSET."""
    shifted_dset: OutputPathType | None
    """Shifted Dataset aligned with the base volume."""
    shifted_child_dsets: OutputPathType | None
    """Shifted child datasets aligned with the base volume."""


def v__align_centers(
    base: InputPathType,
    dset: InputPathType,
    children: list[InputPathType] | None = None,
    echo: bool = False,
    overwrite: bool = False,
    prefix: str | None = None,
    matrix_only: bool = False,
    matrix_only_no_dset: bool = False,
    no_cp: bool = False,
    center_grid: bool = False,
    center_cm: bool = False,
    center_cm_no_amask: bool = False,
    shift_xform: InputPathType | None = None,
    shift_xform_inv: InputPathType | None = None,
    runner: Runner | None = None,
) -> VAlignCentersOutputs:
    """
    Moves the center of a dataset (DSET) to the center of a base volume (BASE) and
    optionally creates a transform matrix.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        base: Base volume, typically a template. Can also specify RAI\
            coordinates for center alignment.
        dset: Dataset to be aligned to BASE.
        children: Additional datasets (originally in register with DSET) that\
            should be shifted in the same way.
        echo: Echo all commands to terminal for debugging.
        overwrite: Overwrite existing output files.
        prefix: Custom prefix for the result files.
        matrix_only: Only output the transform needed to align the centers\
            without shifting any child volumes.
        matrix_only_no_dset: Like -1Dmat_only, but no datasets are created or\
            changed.
        no_cp: Do not create new data; shift existing ones. Use with caution.
        center_grid: Center is that of the volume's grid (default).
        center_cm: Center is the center of mass of the volume.
        center_cm_no_amask: Like -cm, but with no automask.
        shift_xform: Apply shift translation from a 1D file.
        shift_xform_inv: Apply inverse of shift translation from a 1D file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VAlignCentersOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__ALIGN_CENTERS_METADATA)
    cargs = []
    cargs.append("@Align_Centers")
    cargs.append(execution.input_file(base))
    cargs.append(execution.input_file(dset))
    if children is not None:
        cargs.extend([
            "-child",
            *[execution.input_file(f) for f in children]
        ])
    if echo:
        cargs.append("-echo")
    if overwrite:
        cargs.append("-overwrite")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if matrix_only:
        cargs.append("-1Dmat_only")
    if matrix_only_no_dset:
        cargs.append("-1Dmat_only_nodset")
    if no_cp:
        cargs.append("-no_cp")
    if center_grid:
        cargs.append("-grid")
    if center_cm:
        cargs.append("-cm")
    if center_cm_no_amask:
        cargs.append("-cm_no_amask")
    if shift_xform is not None:
        cargs.extend([
            "-shift_xform",
            execution.input_file(shift_xform)
        ])
    if shift_xform_inv is not None:
        cargs.extend([
            "-shift_xform_inv",
            execution.input_file(shift_xform_inv)
        ])
    ret = VAlignCentersOutputs(
        root=execution.output_file("."),
        transform_matrix=execution.output_file(pathlib.Path(dset).name + "_shft.1D"),
        shifted_dset=execution.output_file(prefix + "_shft+orig.BRIK") if (prefix is not None) else None,
        shifted_child_dsets=execution.output_file(prefix + "_child_shft+orig.BRIK") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VAlignCentersOutputs",
    "V__ALIGN_CENTERS_METADATA",
    "v__align_centers",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_TRANSLATE_ANNOTATION_METADATA = Metadata(
    id="d032fa992bc89b8d397cfa5c1c3735e9bf0447e6.boutiques",
    name="mris_translate_annotation",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisTranslateAnnotationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_translate_annotation(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_annotation: OutputPathType
    """The output file with the translated annotation."""


def mris_translate_annotation(
    subject: str,
    hemi: str,
    in_annot: InputPathType,
    translation_file: InputPathType,
    out_annot: str,
    runner: Runner | None = None,
) -> MrisTranslateAnnotationOutputs:
    """
    This program applies a translation table to an annotation file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: The subject identifier.
        hemi: Hemisphere identifier (e.g., lh or rh).
        in_annot: Input annotation file.
        translation_file: Translation table file.
        out_annot: Output annotation file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisTranslateAnnotationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_TRANSLATE_ANNOTATION_METADATA)
    cargs = []
    cargs.append("mris_translate_annotation")
    cargs.append(subject)
    cargs.append(hemi)
    cargs.append(execution.input_file(in_annot))
    cargs.append(execution.input_file(translation_file))
    cargs.append(out_annot)
    ret = MrisTranslateAnnotationOutputs(
        root=execution.output_file("."),
        output_annotation=execution.output_file(out_annot),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_TRANSLATE_ANNOTATION_METADATA",
    "MrisTranslateAnnotationOutputs",
    "mris_translate_annotation",
]
